# ASN.1 module ITS-Container
 OID: _{ itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (102894) cdd (2) version (2) }_

## Data Elements:
### <a name="ItsPduHeader"></a>ItsPduHeader

Common message header for application and facilities layer messages.
 It is included at the beginning of an ITS message as the message header.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Communication information](#Communication+information)_

Fields:
* protocolVersion **INTEGER**  (0..255)<br>
version of the ITS message,

* messageID **INTEGER**  { denm(1), cam(2), poi(3), spatem(4), mapem(5), ivim(6), ev-rsr(7), tistpgtransaction(8), srem(9), ssem(10), evcsn(11), saem(12), rtcmem(13) } (0..255)<br>
Type of the ITS message.
  Following message type values are assigned in the present document:
	- 1 `denm`: Decentralized Environmental Notification Message (DENM) as specified in ETSI EN 302 637-3 [i.3],
  - 2 `cam`: Cooperative Awareness Message (CAM) as specified in ETSI EN 302 637-2 [i.2],
  - 3 `poi`: Point of Interest message as specified in ETSI TS 101 556-1 [i.11],
  - 4 `spatem`: Signal Phase And Timing (SPAT) message as specified in SAE J2735 [i.12] and in ETSI TS 103 301 [i.17],
  - 5 `mapem`: MAP message as specified in SAE J2735 [i.12] and in ETSI TS 103 301 [i.17],
  - 6 `ivim`: In Vehicle Information (IVI) message as defined in ISO TS 19321 [i.13],
  - 7 `ev-rsr`: Electric vehicle recharging spot reservation message, as defined in ETSI TS 101 556-3 [i.14],
  - 8 `tistpgtransaction`: messages for Tyre Information System (TIS) and Tyre Pressure Gauge (TPG) interoperability, as specified in ETSI TS 101 556-2 i.15,
  - 9 `srem`: Traffic light Signal Request Message as specified in ETSI TS 103 301 [i.17],
  - 10 `ssem`: Traffic Light Signal Request Status Message as specified in ETSI TS 103 301 [i.17].
  - 11 `evcsn`: Electrical Vehicle Charging Spot Notification message as specified in ETSI TS 101 556-1 [i.11],
  - 12 `saem`: Services Announcement Extended Message as specified in ETSI TS 102 890-1 i.19,
  - 13 `rtcmem`: Radio Technical Commission for Maritime Services (RTCM) Message as specified in ETSI TS 103 301 [i.17],
  - 14-255: reserved for future usage,

* messageID **INTEGER**  { denm(1), cam(2), poi(3), spatem(4), mapem(5), ivim(6), ev-rsr(7), tistpgtransaction(8), srem(9), ssem(10), evcsn(11), saem(12), rtcmem(13) } (0..255)<br>
* stationID [**StationID**](#StationID) <br>
the identifier of the ITS-S that generates the ITS message in question. It shall be represented as specified in clause A.77 [**StationID**](#StationID).

```asn1
ItsPduHeader ::= SEQUENCE {
    protocolVersion INTEGER (0..255),
    messageID INTEGER { denm(1), cam(2), poi(3), spatem(4), mapem(5), ivim(6), ev-rsr(7), tistpgtransaction(8), srem(9), ssem(10), evcsn(11), saem(12), rtcmem(13) } (0..255),  
    stationID StationID
}
```

### <a name="StationID"></a>StationID

Identifier for an ITS-S.

 The ITS-S ID may be a pseudonym. It may change over space and/or over time.

 The DE is used in [**ActionID**](#ActionID) DF as defined in clause A.102 and [**ItsPduHeader**](#ItsPduHeader) DF as defined in clause A.114.

```asn1
StationID ::= INTEGER(0..4294967295)
```

### <a name="ReferencePosition"></a>ReferencePosition

The geographical position of a position or of an ITS-S. It represents a geographical point position.

 The DF is used in [**ItineraryPath**](#ItineraryPath) DF as defined in clause A.113.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

Fields:
* latitude [**Latitude**](#Latitude) <br>
A latitude of the geographical point; it shall be presented as specified in clause A.41,

* latitude [**Latitude**](#Latitude) <br>
* longitude [**Longitude**](#Longitude) <br>
A longitude of the geographical point; it shall be presented as specified in clause A.44,

* latitude [**Latitude**](#Latitude) <br>
* longitude [**Longitude**](#Longitude) <br>
* positionConfidenceEllipse [**PosConfidenceEllipse**](#PosConfidenceEllipse) <br>
An accuracy of the geographical position; it shall be presented as specified in clause A.119,

* latitude [**Latitude**](#Latitude) <br>
* longitude [**Longitude**](#Longitude) <br>
* positionConfidenceEllipse [**PosConfidenceEllipse**](#PosConfidenceEllipse) <br>
* altitude [**Altitude**](#Altitude) <br>
An altitude and an altitude accuracy of the geographical point; it shall be presented as specified in clause A.103.

```asn1
ReferencePosition ::= SEQUENCE {
    latitude Latitude,
    longitude Longitude,
    positionConfidenceEllipse PosConfidenceEllipse,
    altitude Altitude
}
```

### <a name="DeltaReferencePosition"></a>DeltaReferencePosition

Defines a geographical point position as offset position to a reference geographical point.

 The DF is used in [**EventPoint**](#EventPoint) DF as defined in clause A.111 and in [**PathPoint**](#PathPoint) DF as defined in clause A.118

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

Fields:
* deltaLatitude [**DeltaLatitude**](#DeltaLatitude) <br>
A delta latitude offset with regards to the latitude value of the reference position.
   It shall be presented as defined in clause A.20

* deltaLatitude [**DeltaLatitude**](#DeltaLatitude) <br>
* deltaLongitude [**DeltaLongitude**](#DeltaLongitude) <br>
A delta longitude offset with regards to the longitude value of the reference position.
   It shall be presented as defined in clause A.21

* deltaLatitude [**DeltaLatitude**](#DeltaLatitude) <br>
* deltaLongitude [**DeltaLongitude**](#DeltaLongitude) <br>
* deltaAltitude [**DeltaAltitude**](#DeltaAltitude) <br>
A delta altitude offset with regards to the altitude value of the reference position.
   It shall be presented as defined in clause A.19

```asn1
DeltaReferencePosition ::= SEQUENCE {
    deltaLatitude DeltaLatitude,
    deltaLongitude DeltaLongitude,
    deltaAltitude DeltaAltitude
}
```

### <a name="Longitude"></a>Longitude

Absolute geographical longitude in a WGS84 co-ordinate system, providing a range of 180 degrees
 to the east or to the west of the prime meridian.

 - Negative values are used for longitudes to the west,
 - Positive values are used for longitudes to the east.
 - When the information is unavailable, the value shall be set to _1 800 000 001_.

 The DE is used in
 [**CenDsrcTollingZone**](#CenDsrcTollingZone) DF as defined in clause A.105,
 [**ProtectedCommunicationZone**](#ProtectedCommunicationZone) DF as defined in clause A.121 and
 [**ReferencePosition**](#ReferencePosition) DF as defined in clause A.124.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 microdegree_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

```asn1
Longitude ::= INTEGER {
    oneMicrodegreeEast (10),
    oneMicrodegreeWest (-10),
    unavailable(1800000001)
} (-1800000000..1800000001)
```

### <a name="Latitude"></a>Latitude

Absolute geographical latitude in a WGS84 coordinate system, providing a range of 90 degrees in north or
 in south hemisphere.

 - Positive values are used for latitude in north of the Equator,
 - Negative values are used for latitude in south of the Equator.
 - When the information is unavailable, the value shall be set to _900 000 001_.

 The DE is used in
 [**CenDsrcTollingZone**](#CenDsrcTollingZone) DF as defined in clause A.105,
 [**ProtectedCommunicationZone**](#ProtectedCommunicationZone) DF as defined in clause A.121 and
 [**ReferencePosition**](#ReferencePosition) DF as defined in clause A.124.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 microdegree_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

```asn1
Latitude ::= INTEGER {
    oneMicrodegreeNorth (10),
    oneMicrodegreeSouth (-10),
    unavailable(900000001)
} (-900000000..900000001)
```

### <a name="Altitude"></a>Altitude

Altitude and accuracy of an altitude in a WGS84 co-ordinate system.

 This DF is used in [**ReferencePosition**](#ReferencePosition) DF as defined in clause A.124.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

Fields:
* altitudeValue [**AltitudeValue**](#AltitudeValue) <br>
altitude of a geographical point.
        It shall be presented as specified in clause A.9 AltitudeValue,

* altitudeValue [**AltitudeValue**](#AltitudeValue) <br>
* altitudeConfidence [**AltitudeConfidence**](#AltitudeConfidence) <br>
accuracy of the reported altitudeValue within a specific confidence level.
        It shall be presented as specified in clause A.8.

```asn1
Altitude ::= SEQUENCE {
    altitudeValue AltitudeValue,
    altitudeConfidence AltitudeConfidence
}
```

### <a name="AltitudeValue"></a>AltitudeValue

Altitude in a WGS84 co-ordinate system.
 - When the information is not available, the DE shall be set to _800 001_.
 - For altitude equal or greater than _8 000 m_, the DE shall be set to _800 000_.
 - For altitude equal or less than _-1 000_ m, the DE shall be set to  _100 000_.

 The DE is used in [**Altitude**](#Altitude) DF as defined in clause A.103.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 meter_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

```asn1
AltitudeValue ::= INTEGER {
    referenceEllipsoidSurface(0),
    oneCentimeter(1),
    unavailable(800001)
} (-100000..800001)
```

### <a name="AltitudeConfidence"></a>AltitudeConfidence

Absolute accuracy of a reported altitude value of a geographical point for a predefined confidence level (e.g. 95 %).
 The required confidence level is defined by the corresponding standards applying the usage of this DE.

 The DE is used in [**Altitude**](#Altitude) DF as defined in clause A.103

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The fact that an altitude value is received with confidence set to `unavailable(15)` can be caused
 by several reasons, such as:
 - the sensor cannot deliver the accuracy at the defined confidence level because it is a low-end sensor,
 - the sensor cannot calculate the accuracy due to lack of variables, or
 - there has been a vehicle bus (e.g. CAN bus) error.
 In all 3 cases above, the reported altitude value may be valid and used by the application.
 {: .note}


 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: If an altitude value is received and its confidence is set to `outOfRange(14)`, it means that the reported
 altitude value is not valid and therefore cannot be trusted. Such value is not useful for the application.
 {: .note}


 The value shall be set to:
   - 0 `alt-000-01` if the altitude accuracy is equal to or less than 0,01 metre
   - 1 `alt-000-02` if the altitude accuracy is equal to or less than 0,02 metre
   - 2 `alt-000-05` if the altitude accuracy is equal to or less than 0,05 metre
   - 3 `alt-000-10` if the altitude accuracy is equal to or less than 0,1 metre
   - 4 `alt-000-20` if the altitude accuracy is equal to or less than 0,2 metre
   - 5 `alt-000-50` if the altitude accuracy is equal to or less than 0,5 metre
   - 6 `alt-001-00` if the altitude accuracy is equal to or less than 1 metre
   - 7 `alt-002-00` if the altitude accuracy is equal to or less than 2 metres
   - 8 `alt-005-00` if the altitude accuracy is equal to or less than 5 metres
   - 9 `alt-010-00` if the altitude accuracy is equal to or less than 10 metres
   - 10 `alt-020-00` if the altitude accuracy is equal to or less than 20 metres
   - 11 `alt-050-00` if the altitude accuracy is equal to or less than 50 metres
   - 12 `alt-100-00` if the altitude accuracy is equal to or less than 100 metres
   - 13 `alt-200-00` if the altitude accuracy is equal to or less than 200 metres
   - 14 `outOfRange` if the altitude accuracy is out of range, i.e. greater than 200 metres
   - 15 `unavailable` if the altitude accuracy information is unavailable

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

```asn1
AltitudeConfidence ::= ENUMERATED {
    alt-000-01 (0),
    alt-000-02 (1),
    alt-000-05 (2),
    alt-000-10 (3),
    alt-000-20 (4),
    alt-000-50 (5),
    alt-001-00 (6),
    alt-002-00 (7),
    alt-005-00 (8),
    alt-010-00 (9),
    alt-020-00 (10),
    alt-050-00 (11),
    alt-100-00 (12),
    alt-200-00 (13),
    outOfRange (14),
    unavailable (15)
}
```

### <a name="DeltaLongitude"></a>DeltaLongitude

It defines an offset longitude with regards to a referred longitude value.
 It may be used to describe a geographical point with regards to a specific reference geographical position.

 - Positive values are used for providing offset towards the east from the reference position.
 - Negative values are used for providing offset towards the west from the reference position.
 - When the information is unavailable, the value shall be set to _131072_.

 The DE is used in [**DeltaReferencePosition**](#DeltaReferencePosition) DF as defined in clause A.109.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 microdegree_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

```asn1
DeltaLongitude ::= INTEGER {
    oneMicrodegreeEast (10),
    oneMicrodegreeWest (-10),
    unavailable (131072)
} (-131071..131072)
```

### <a name="DeltaLatitude"></a>DeltaLatitude

It defines offset latitude with regards to a referred latitude value.
 It may be used to describe a geographical point with regards to a specific reference geographical position.

 - Positive values are used for providing offset towards the north from the reference position.
 - Negative values are used for providing offset towards the south from the reference position.
 - When the information is unavailable, the value shall be set to _131072_.

 The DE is used in [**DeltaReferencePosition**](#DeltaReferencePosition) DF as defined in clause A.109.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 microdegree_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

```asn1
DeltaLatitude ::= INTEGER {
    oneMicrodegreeNorth (10),
    oneMicrodegreeSouth (-10) ,
    unavailable (131072)
} (-131071..131072)
```

### <a name="DeltaAltitude"></a>DeltaAltitude

It defines an offset altitude with regards to a referred altitude value.
 It may be used to describe a geographical point with regards to a specific reference geographical position.

 - Positive values are used for providing altitude offset above the reference position.
 - For values equal or greater than _127,99 metres_, the value shall be _12 799_.
 - Negative values are used for providing altitude offset below the reference position.
 - When the information is unavailable, the value shall be set to _12 800_.

 The DE is used in [**DeltaReferencePosition**](#DeltaReferencePosition) DF as defined in clause A.109.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 metre_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

```asn1
DeltaAltitude ::= INTEGER {
    oneCentimeterUp (1),
    oneCentimeterDown (-1),
    unavailable (12800)
} (-12700..12800)
```

### <a name="PosConfidenceEllipse"></a>PosConfidenceEllipse

This data field provides the horizontal position accuracy in a shape of ellipse with a predefined
 confidence level (e.g. 95 %). The centre of the ellipse shape corresponds to the reference
 position point for which the position accuracy is evaluated.

 The required confidence level of the position accuracy is defined by ITS message or ITS application applying this DF.

 The DF is used in [**ReferencePosition**](#ReferencePosition) DF as defined in clause A.124.

Fields:
* semiMajorConfidence [**SemiAxisLength**](#SemiAxisLength) <br>
half of length of the major axis, i.e. distance between the centre point
         and major axis point of the position accuracy ellipse. It shall be presented as specified
         in clause A.67,

* semiMajorConfidence [**SemiAxisLength**](#SemiAxisLength) <br>
* semiMinorConfidence [**SemiAxisLength**](#SemiAxisLength) <br>
half of length of the minor axis, i.e. distance between the centre point
         and minor axis point of the position accuracy ellipse. It shall be presented as specified
         in clause A.67,

* semiMajorConfidence [**SemiAxisLength**](#SemiAxisLength) <br>
* semiMinorConfidence [**SemiAxisLength**](#SemiAxisLength) <br>
* semiMajorOrientation [**HeadingValue**](#HeadingValue) <br>
orientation direction of the ellipse major axis of the position accuracy
         ellipse with regards to the WGS84 north. It shall be presented as specified in clause A.35.

```asn1
PosConfidenceEllipse ::= SEQUENCE {
    semiMajorConfidence SemiAxisLength,
    semiMinorConfidence SemiAxisLength,
    semiMajorOrientation HeadingValue
}
```

### <a name="PathPoint"></a>PathPoint

The DF that defines a waypoint position within a path.

 The DE is used in [**PathHistory**](#PathHistory) DF as defined in clause A.117.
 @category GeoReference information

Fields:
* pathPosition [**DeltaReferencePosition**](#DeltaReferencePosition) <br>
The waypoint position defined as an offset position with regards to a pre-defined
        reference position. It shall be presented as specified in clause A.109

* pathPosition [**DeltaReferencePosition**](#DeltaReferencePosition) <br>
* pathDeltaTime [**PathDeltaTime**](#PathDeltaTime)  OPTIONAL<br>
The travel time separated from a waypoint to the predefined reference position.
        It shall be presented as specified in clause A.47.
        This field is __OPTIONAL__. It shall be present if the information is available.

```asn1
PathPoint ::= SEQUENCE {
    pathPosition DeltaReferencePosition,
    pathDeltaTime PathDeltaTime OPTIONAL
}
```

### <a name="PathDeltaTime"></a>PathDeltaTime

This DE defines the recorded or estimated travel time separated between a position and a predefined
 reference position. It may be used to describe the historical path travelled by an ITS-S in mobility
 (e.g. vehicle ITS-S) as specified in ETSI EN 302 637 2 [i.2].

 The DE is used in [**EventPoint**](#EventPoint) DF as defined in clause A.111 and [**PathPoint**](#PathPoint) DF as defined in clause A.118.
 @category GeoReference information

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.01 second_

```asn1
PathDeltaTime ::= INTEGER {tenMilliSecondsInPast(1)} (1..65535, ...)
```

### <a name="PtActivation"></a>PtActivation

Real-time systems designed for operations control, traffic light priorities, track switches, barriers, etc.
 using a range of activation devices equipped in public transport vehicles.

 The activation of the corresponding equipment is triggered by the approach or passage of a public transport
 vehicle at a certain point (e.g. a beacon).

 Today there are different payload variants defined for public transport activation-data. The R09.x is one of
 the industry standard used by public transport vehicles (e.g. buses, trams) in Europe (e.g. Germany Austria)
 for controlling traffic lights, barriers, bollards, etc. This DF includes information like route, course,
 destination, priority, etc.

 The R09.x content is defined in VDV recommendation 420 [i.8]. It includes following information:
 - Priority Request Information (pre-request, request, ready to start)
 - End of Prioritization procedure
 - Priority request direction
 - Public Transport line number
 - Priority of public transport
 - Route line identifier of the public transport
 - Route number identification
 - Destination of public transport vehicle

 Other countries may use different message sets defined by the local administration.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

Fields:
* ptActivationType [**PtActivationType**](#PtActivationType) <br>
type of activation. It shall be presented as defined in clause A.60

```asn1
PtActivation ::= SEQUENCE {
    ptActivationType PtActivationType,
    ptActivationData PtActivationData
}
```

### <a name="PtActivationType"></a>PtActivationType

This DE indicates a certain coding type of the PtActivationData data.
 - `0`: undefined coding type,
 - `1`: coding of PtActivationData conform to VDV recommendation 420 [i.8],
 - `2`: coding of PtActivationData based on VDV recommendation 420 [i.8].
 - values 3 to 255 are reserved for alternative and future use.

 The DE is used in [**PtActivation**](#PtActivation) DF as defined in clause A.123.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
PtActivationType ::= INTEGER {undefinedCodingType(0), r09-16CodingType(1), vdv-50149CodingType(2)} (0..255)
```

### <a name="PtActivationData"></a>PtActivationData

The DE used for various tasks in the public transportation environment, especially for controlling traffic
 signal systems to prioritize and speed up public transportation in urban area (e.g. intersection "_bottlenecks_").
 The traffic lights may be controlled by an approaching bus or tram automatically. This permits "_In Time_" activation
 of the green phase, will enable the individual traffic to clear a potential traffic jam in advance. Thereby the
 approaching bus or tram may pass an intersection with activated green light without slowing down the speed due to
 traffic congestion. Other usage of the DE is the provision of information like the public transport line number
 or the schedule delay of a public transport vehicle.

 The DE is used in [**PtActivation**](#PtActivation) DF as defined in clause A.123.

```asn1
PtActivationData ::= OCTET STRING (SIZE(1..20))
```

### <a name="AccelerationControl"></a>AccelerationControl

Current controlling mechanism for longitudinal movement of the vehicle.
 The data may be provided via the in-vehicle network. It indicates whether a specific in-vehicle
 acceleration control system is engaged or not. Currently, this DE includes the information of the
 vehicle brake pedal, gas pedal, emergency brake system, collision warning system, adaptive cruise
 control system, cruise control system and speed limiter system.

 The corresponding bit shall be set to 1 under the following conditions:
 - 0 `brakePedalEngaged`      : Driver is stepping on the brake pedal,
 - 1 `gasPedalEngaged`        : Driver is stepping on the gas pedal,
 - 2 `emergencyBrakeEngaged`  : emergency brake system is engaged,
 - 3 `collisionWarningEngaged`: collision warning system is engaged,
 - 4 `accEngaged`             : ACC is engaged,
 - 5 `cruiseControlEngaged`   : cruise control is engaged,
 - 6 `speedLimiterEngaged`    : speed limiter is engaged.

 Otherwise (for example when the corresponding system is not available due to non equipped system
 or information is unavailable), the corresponding bit shall be set to _0_.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The system engagement condition is OEM specific and therefore out of scope of the present document.
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
AccelerationControl ::= BIT STRING {
    brakePedalEngaged (0),
    gasPedalEngaged (1),
    emergencyBrakeEngaged (2),
    collisionWarningEngaged (3),
    accEngaged (4),
    cruiseControlEngaged (5),
    speedLimiterEngaged (6)
} (SIZE(7))
```

### <a name="SemiAxisLength"></a>SemiAxisLength

Absolute position accuracy in one of the axis direction as defined in a shape of ellipse with a predefined
 confidence level (e.g. 95 %). The required confidence level is defined by the corresponding standards applying the DE.

 The value shall be set to:
 - `1` if the accuracy is equal to or less than 1 cm,
 - `n (n > 1 and n < 4 093)` if the accuracy is equal to or less than n cm,
 - `4 093` if the accuracy is equal to or less than 4 093 cm,
 - `4 094` if the accuracy is out of range, i.e. greater than 4 093 cm,
 - `4 095` if the accuracy information is unavailable.

 The DE is used in [**PosConfidenceEllipse**](#PosConfidenceEllipse) DF as defined in clause A.119.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The fact that a position coordinate value is received with confidence set to 'unavailable(4095)'
 can be caused by several reasons, such as:
 - the sensor cannot deliver the accuracy at the defined confidence level because it is a low-end sensor,
 - the sensor cannot calculate the accuracy due to lack of variables, or
 - there has been a vehicle bus (e.g. CAN bus) error.
 In all 3 cases above, the reported position coordinate value may be valid and used by the application.
 If a position coordinate value is received and its confidence is set to 'outOfRange(4094)', it means that
 the reported position coordinate value is not valid and therefore cannot be trusted. Such value is not useful
 for the application.
 {: .note}

```asn1
SemiAxisLength ::= INTEGER{oneCentimeter(1), outOfRange(4094), unavailable(4095)} (0..4095)
```

### <a name="CauseCode"></a>CauseCode

Encoded value of a traffic event type.

 The values of `causeCodeType` and `subCauseCode` are defined in clause 7.1.4 of ETSI EN 302 637-3 [i.3].

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

Fields:
* causeCode [**CauseCodeType**](#CauseCodeType) <br>
the type of a direct cause of a detected event. It shall be presented as defined in clause A.10

* causeCode [**CauseCodeType**](#CauseCodeType) <br>
* subCauseCode [**SubCauseCodeType**](#SubCauseCodeType) <br>
sub type of the direct cause. It shall be presented as defined in clause A.81

```asn1
CauseCode ::= SEQUENCE {
    causeCode CauseCodeType,
    subCauseCode SubCauseCodeType,
        ...
}
```

### <a name="CauseCodeType"></a>CauseCodeType

Value of the direct cause code of a detected event as defined in ETSI EN 302 637 3 [i.3].
 The value is assigned according to the clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The cause codes are described as following:
 - 0  reserved for future use,
 - 1 `trafficCondition`                    : the type of event is an abnormal traffic condition,
 - 2 `accident`                            : the type of event is a road accident,
 - 3 `roadworks`                           : the type of event is roadwork,
 - 4 reserved for future usage,
 - 5 `impassability`                       : the type of event is unmanaged road blocking, referring to any
                                             blocking of a road, partial or total, which has not been adequately
                                             secured and signposted,
 - 6 `adverseWeatherCondition-Adhesion`    : the type of event is low adhesion,
 - 7 `aquaplaning`                         : danger of aquaplaning on the road,
 - 8 reserved for future usage,
 - 9 `hazardousLocation-SurfaceCondition`  : the type of event is abnormal road surface condition,
 - 10 `hazardousLocation-ObstacleOnTheRoad`: the type of event is obstacle on the road,
 - 11 `hazardousLocation-AnimalOnTheRoad`  : the type of event is animal on the road,
 - 12 `humanPresenceOnTheRoad`             : the type of event is human presence on the road,
 - 13 reserved for future usage,
 - 14 `wrongWayDriving`                    : the type of the event is vehicle driving in wrong way,
 - 15 `rescueAndRecoveryWorkInProgress`    : the type of event is rescue and recovery work for accident or for a road hazard in progress,
 - 16 reserved for future usage,
 - 17 `adverseWeatherCondition-ExtremeWeatherCondition`: the type of event is extreme weather condition,
 - 18 `adverseWeatherCondition-Visibility`             : the type of event is low visibility,
 - 19 `adverseWeatherCondition-Precipitation`          : the type of event is precipitation,
 - 20-25 reserved for future usage,
 - 26 `slowVehicle`                        : the type of event is slow vehicle driving on the road,
 - 27 `dangerousEndOfQueue`                : the type of event is dangerous end of vehicle queue,
 - 28-90 are reserved for future usage,
 - 91 `vehicleBreakdown`                   : the type of event is break down vehicle on the road,
 - 92 `postCrash`                          : the type of event is a detected crash,
 - 93 `humanProblem`                       : the type of event is human health problem in vehicles involved in traffic,
 - 94 `stationaryVehicle`                  : the type of event is stationary vehicle,
 - 95 `emergencyVehicleApproaching`        : the type of event is approaching vehicle operating emergency mission,
 - 96 `hazardousLocation-DangerousCurve`   : the type of event is dangerous curve,
 - 97 `collisionRisk`                      : the type of event is a collision risk,
 - 98 `signalViolation`                    : the type of event is signal violation,
 - 99 `dangerousSituation`                 : the type of event is dangerous situation in which autonomous safety system in vehicle is activated,
 - 100-255 are reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
CauseCodeType ::= INTEGER {
    reserved (0),
    trafficCondition (1),
    accident (2),
    roadworks (3),
    impassability (5),
    adverseWeatherCondition-Adhesion (6),
    aquaplannning (7),
    hazardousLocation-SurfaceCondition (9),
    hazardousLocation-ObstacleOnTheRoad (10),
    hazardousLocation-AnimalOnTheRoad (11),
    humanPresenceOnTheRoad (12),
    wrongWayDriving (14),
    rescueAndRecoveryWorkInProgress (15),
    adverseWeatherCondition-ExtremeWeatherCondition (17),
    adverseWeatherCondition-Visibility (18),
    adverseWeatherCondition-Precipitation (19),
    slowVehicle (26),
    dangerousEndOfQueue (27),
    vehicleBreakdown (91),
    postCrash (92),
    humanProblem (93),
    stationaryVehicle (94),
    emergencyVehicleApproaching (95),
    hazardousLocation-DangerousCurve (96),
    collisionRisk (97),
    signalViolation (98),
    dangerousSituation (99)
} (0..255)
```

### <a name="SubCauseCodeType"></a>SubCauseCodeType

Type of sub cause of a detected event as defined in ETSI EN 302 637-3 [i.3].

 For DENM usage, the value as given in clause 7.1.4 of ETSI EN 302 637-3 [i.3] apply.

 The DE is used in CauseCode DF as defined in clause A.104.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE1**: The sub cause code value assignment varies based on value of causeCode as defined in clause A.10.
 {: .note}


 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE2**: Complete list of all possible sub cause code values as given in ETSI EN 302 637-3 [i.3] is provided
 in the present document for information. For example, see clause A.3 for sub cause code of accident event.
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_ 

```asn1
SubCauseCodeType ::= INTEGER (0..255)
```

### <a name="TrafficConditionSubCauseCode"></a>TrafficConditionSubCauseCode

Encoded value of the sub cause codes of the event type `trafficCondition` as defined in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`                 : in case further detailed information on traffic jam is unavailable,
 - 1 `increasedVolumeOfTraffic`    : in case detected jam volume is increased,
 - 2 `trafficJamSlowlyIncreasing`  : in case detected traffic jam volume is increasing slowly,
 - 3 `trafficJamIncreasing`        : in case traffic jam volume is increasing,
 - 4 `trafficJamStronglyIncreasing`: in case traffic jam volume is strongly increasing,
 - 5 `trafficStationary`           : in case traffic is stationary,
 - 6 `trafficJamSlightlyDecreasing`: in case traffic jam volume is decreasing slowly,
 - 7 `trafficJamDecreasing`        : in case traffic jam volume is decreasing,
 - 8 `trafficJamStronglyDecreasing`: in case traffic jam volume is decreasing rapidly,
 - 9-255: reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
TrafficConditionSubCauseCode ::= INTEGER {
    unavailable(0),
    increasedVolumeOfTraffic(1),
    trafficJamSlowlyIncreasing(2),
    trafficJamIncreasing(3),
    trafficJamStronglyIncreasing(4),
    trafficStationary(5),
    trafficJamSlightlyDecreasing(6),
    trafficJamDecreasing(7),
    trafficJamStronglyDecreasing(8)
} (0..255)
```

### <a name="AccidentSubCauseCode"></a>AccidentSubCauseCode

Encoded value of the sub cause codes of the event type `accident` as defined in clause A.10 of ETSI TS 102 859-2.
 Sub event cause and value setting rule is defined according to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`                        : in case the information on the sub cause of the accident is unavailable,
 - 1 `multiVehicleAccident`               : in case more than two vehicles are involved in accident,
 - 2 `heavyAccident`                      : in case the airbag of the vehicle involved in the accident is triggered,
                                             the accident requires important rescue and/or recovery work,
 - 3 `accidentInvolvingLorry`             : in case the accident involves a lorry,
 - 4 `accidentInvolvingBus`               : in case the accident involves a bus,
 - 5 `accidentInvolvingHazardousMaterials`: in case the accident involves hazardous material,
 - 6 `accidentOnOppositeLane`             : in case the accident happens on opposite lanes,
 - 7 `unsecuredAccident`                  : in case the accident is not secured,
 - 8 `assistanceRequested`                : in case rescue and assistance are requested,
 - 9-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
AccidentSubCauseCode ::= INTEGER {
    unavailable(0),
    multiVehicleAccident(1),
    heavyAccident(2),
    accidentInvolvingLorry(3),
    accidentInvolvingBus(4),
    accidentInvolvingHazardousMaterials(5),
    accidentOnOppositeLane(6),
    unsecuredAccident(7),
    assistanceRequested(8)
} (0..255)
```

### <a name="RoadworksSubCauseCode"></a>RoadworksSubCauseCode

Encoded value of the sub cause codes of the event type `roadworks` as defined in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according to
 clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`                 : in case further detailed information on roadworks is unavailable,
 - 1 `majorRoadworks`              : in case a major roadworks is ongoing,
 - 2 `roadMarkingWork`             : in case a road marking work is ongoing,
 - 3 `slowMovingRoadMaintenance`   : in case slow moving road maintenance work is ongoing,
 - 4 `shortTermStationaryRoadworks`: in case a short term stationary roadwork is ongoing,
 - 5 `streetCleaning`              : in case a vehicle street cleaning work is ongoing,
 - 6 `winterService`               : in case winter service work is ongoing,
 - 7-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
RoadworksSubCauseCode ::= INTEGER {unavailable(0), majorRoadworks(1), roadMarkingWork(2), slowMovingRoadMaintenance(3), shortTermStationaryRoadworks(4), streetCleaning(5), winterService(6)} (0..255)
```

### <a name="HumanPresenceOnTheRoadSubCauseCode"></a>HumanPresenceOnTheRoadSubCauseCode

Encoded value of the sub cause codes of the event type `humanPresenceOnTheRoad` as defined in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according to
 clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`          : in case further detailed information on human presence on the road is unavailable,
 - 1 `childrenOnRoadway`    : in case children are detected on the road event,
 - 2 `cyclistOnRoadway`     : in case cyclist presence is detected on the road,
 - 3 `motorcyclistOnRoadway`: in case motorcyclist presence is detected on the road,
 - 4-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
HumanPresenceOnTheRoadSubCauseCode ::= INTEGER {unavailable(0), childrenOnRoadway(1), cyclistOnRoadway(2), motorcyclistOnRoadway(3)} (0..255)
```

### <a name="WrongWayDrivingSubCauseCode"></a>WrongWayDrivingSubCauseCode

Encoded value of the sub cause codes of the event type `wrongWayDriving` as defined in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`: in case further detailed information on wrong way driving event is unavailable,
 - 1 `wrongLane`: in case vehicle is driving on a lane for which it has no authorization to use,
 - 2 `wrongDirection`: in case vehicle is driving in a direction that it is not allowed,
 - 3-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
WrongWayDrivingSubCauseCode ::= INTEGER {unavailable(0), wrongLane(1), wrongDirection(2)} (0..255)
```

### <a name="AdverseWeatherCondition-ExtremeWeatherConditionSubCauseCode"></a>AdverseWeatherCondition-ExtremeWeatherConditionSubCauseCode

Encoded value of the sub cause codes of the event type `adverseWeatherCondition-ExtremeWeatherCondition` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable` : in case information on the type of extreme weather condition is unavailable
 - 1 `strongWinds` : in case the type of extreme weather condition is strong wind
 - 2 `damagingHail`: in case the type of extreme weather condition is damaging hail
 - 3 `hurricane`   : in case the type of extreme weather condition is hurricane
 - 4 `thunderstorm`: in case the type of extreme weather condition is thunderstorm
 - 5 `tornado`     : in case the type of extreme weather condition is tornado
 - 6 `blizzard`    : in case the type of extreme weather condition is blizzard
 - 7-255 reserved for future usage

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
AdverseWeatherCondition-ExtremeWeatherConditionSubCauseCode ::= INTEGER {
    unavailable(0),
    strongWinds(1),
    damagingHail(2),
    hurricane(3),
    thunderstorm(4),
    tornado(5),
    blizzard(6)
} (0..255)
```

### <a name="AdverseWeatherCondition-AdhesionSubCauseCode"></a>AdverseWeatherCondition-AdhesionSubCauseCode

Encoded value of the sub cause codes of the event type `adverseWeatherCondition-Adhesion` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`     : in case information on the cause of the low road adhesion is unavailable
 - 1 `heavyFrostOnRoad`: in case the low road adhesion is due to heavy frost on the road
 - 2 `fuelOnRoad`      : in case the low road adhesion is due to fuel on the road
 - 3 `mudOnRoad`       : in case the low road adhesion is due to mud on the road
 - 4 `snowOnRoad`      : in case the low road adhesion is due to snow on the road
 - 5 `iceOnRoad`       : in case the low road adhesion is due to ice on the road
 - 6 `blackIceOnRoad`  : in case the low road adhesion is due to black ice on the road
 - 7 `oilOnRoad`       : in case the low road adhesion is due to oil on the road
 - 8 `looseChippings`  : in case the low road adhesion is due to loose gravel or stone fragments detached from a road surface or from a hazard
 - 9 `instantBlackIce` : in case the low road adhesion is due to instant black ice on the road surface
 - 10 `roadsSalted`    : when the low road adhesion is due to salted road
 - 11-255 reserved for future usage

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
AdverseWeatherCondition-AdhesionSubCauseCode ::= INTEGER {
    unavailable(0),
    heavyFrostOnRoad(1),
    fuelOnRoad(2),
    mudOnRoad(3),
    snowOnRoad(4),
    iceOnRoad(5),
    blackIceOnRoad(6),
    oilOnRoad(7),
    looseChippings(8),
    instantBlackIce(9),
    roadsSalted(10)
} (0..255)
```

### <a name="AdverseWeatherCondition-VisibilitySubCauseCode"></a>AdverseWeatherCondition-VisibilitySubCauseCode

Encoded value of the sub cause codes of the event type `adverseWeatherCondition-Visibility` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according to clause 7.1.4 of ETSI EN 302 637-3 [i.3].
  The sub causes are described as following:
 - 0 `unavailable`    : in case information on the cause of low visibility is unavailable
 - 1 `fog`            : in case the cause of low visibility is fog
 - 2 `smoke`          : in case the cause of low visibility is smoke
 - 3 `heavySnowfall`  : in case the cause of low visibility is heavy snow fall
 - 4 `heavyRain`      : in case the cause of low visibility is heavy rain
 - 5 `heavyHail`      : in case the cause of low visibility is heavy hail
 - 6 `lowSunGlare`    : in case the cause of low visibility is sun glare
 - 7 `sandstorms`     : in case the cause of low visibility is sand storm
 - 8 `swarmsOfInsects`: in case the cause of low visibility is swarm of insects
 - 9-255 reserved for future usage

 @category: Traffic information

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
AdverseWeatherCondition-VisibilitySubCauseCode ::= INTEGER {
    unavailable(0),
    fog(1),
    smoke(2),
    heavySnowfall(3),
    heavyRain(4),
    heavyHail(5),
    lowSunGlare(6),
    sandstorms(7),
    swarmsOfInsects(8)
} (0..255)
```

### <a name="AdverseWeatherCondition-PrecipitationSubCauseCode"></a>AdverseWeatherCondition-PrecipitationSubCauseCode

Encoded value of the sub cause codes of the event type `adverseWeatherCondition-Precipitation` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`: in case information on the type of precipitation is unavailable
 - 1 `heavyRain`: in case the type of precipitation is heavy rain
 - 2 `heavySnowfall`: in case the type of precipitation is heavy snow fall
 - 3 `softHail`: in case the type of precipitation is soft hail
 - 4-255 reserved for future usage

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
AdverseWeatherCondition-PrecipitationSubCauseCode ::= INTEGER {
    unavailable(0),
    heavyRain(1),
    heavySnowfall(2),
    softHail(3)
} (0..255)
```

### <a name="SlowVehicleSubCauseCode"></a>SlowVehicleSubCauseCode

Encoded value of the sub cause codes of the event type "slowVehicle" as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`                    : in case further detailed information on slow vehicle driving event is
                                        unavailable,
 - 1 `maintenanceVehicle`             : in case of a slow driving maintenance vehicle on the road,
 - 2 `vehiclesSlowingToLookAtAccident`: in case vehicle is temporally slowing down to look at accident, spot, etc.,
 - 3 `abnormalLoad`                   : in case an abnormal loaded vehicle is driving slowly on the road,
 - 4 `abnormalWideLoad`               : in case an abnormal wide load vehicle is driving slowly on the road,
 - 5 `convoy`                         : in case of slow driving convoy on the road,
 - 6 `snowplough`                     : in case of slow driving snow plough on the road,
 - 7 `deicing`                        : in case of slow driving de-icing vehicle on the road,
 - 8 `saltingVehicles`                : in case of slow driving salting vehicle on the road,
 - 9-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
SlowVehicleSubCauseCode ::= INTEGER {unavailable(0), maintenanceVehicle(1), vehiclesSlowingToLookAtAccident(2), abnormalLoad(3), abnormalWideLoad(4), convoy(5), snowplough(6), deicing(7), saltingVehicles(8)} (0..255)
```

### <a name="StationaryVehicleSubCauseCode"></a>StationaryVehicleSubCauseCode

Encoded value of the sub cause codes of the event type "stationaryVehicle" as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`           : in case further detailed information on stationary vehicle is unavailable,
 - 1 `humanProblem`          : in case stationary vehicle is due to health problem of driver or passenger,
 - 2 `vehicleBreakdown`      : in case stationary vehicle is due to vehicle break down,
 - 3 `postCrash`             : in case stationary vehicle is caused by collision,
 - 4 `publicTransportStop`   : in case public transport vehicle is stationary at bus stop,
 - 5 `carryingDangerousGoods`: in case the stationary vehicle is carrying dangerous goods,
 - 6-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
StationaryVehicleSubCauseCode ::= INTEGER {unavailable(0), humanProblem(1), vehicleBreakdown(2), postCrash(3), publicTransportStop(4), carryingDangerousGoods(5)} (0..255)
```

### <a name="HumanProblemSubCauseCode"></a>HumanProblemSubCauseCode

Encoded value of the sub cause codes of the event type "humanProblem" as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 - The sub causes are described as following:
 - 0 `unavailable`    : in case further detailed information on human health problem is unavailable,
 - 1 `glycemiaProblem`: in case human problem is due to glycaemia problem,
 - 2 `heartProblem`   : in case human problem is due to heart problem,
 - 3-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
HumanProblemSubCauseCode ::= INTEGER {unavailable(0), glycemiaProblem(1), heartProblem(2)} (0..255)
```

### <a name="EmergencyVehicleApproachingSubCauseCode"></a>EmergencyVehicleApproachingSubCauseCode

Encoded value of the sub cause codes of the event type "emergencyVehicleApproaching" as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`                  : in case further detailed information on the emergency vehicle approaching event
                                      is unavailable,
 - 1 `emergencyVehicleApproaching`  : in case an operating emergency vehicle is approaching,
 - 2 `prioritizedVehicleApproaching`: in case a prioritized vehicle (e.g. bus) is approaching,
 - value 3-255  reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
EmergencyVehicleApproachingSubCauseCode ::= INTEGER {unavailable(0), emergencyVehicleApproaching(1), prioritizedVehicleApproaching(2)} (0..255)
```

### <a name="HazardousLocation-DangerousCurveSubCauseCode"></a>HazardousLocation-DangerousCurveSubCauseCode

Encoded value of the sub cause codes of the event type `hazardousLocation-DangerousCurve` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`              : in case further detailed information on the dangerous curve is unavailable,
 - 1 `dangerousLeftTurnCurve`   : in case the dangerous curve is a left turn curve,
 - 2 `dangerousRightTurnCurve`  : in case the dangerous curve is a right turn curve,
 - 3 `multipleCurvesStartingWithUnknownTurningDirection`: in case of multiple curves for which the starting curve turning direction is not known,
 - 4 `multipleCurvesStartingWithLeftTurn`: in case of multiple curves starting with a left turn curve,
 - 5 `multipleCurvesStartingWithRightTurn`: in case of multiple curves stating with a right turn curve,
 - value 6-255 reserved for future usage.

 The definition of whether a curve is dangerous may vary according to region and according to vehicle types/mass
 and vehicle speed driving on the curve. This definition is out of scope of the present document.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
HazardousLocation-DangerousCurveSubCauseCode ::= INTEGER {unavailable(0), dangerousLeftTurnCurve(1), dangerousRightTurnCurve(2), multipleCurvesStartingWithUnknownTurningDirection(3), multipleCurvesStartingWithLeftTurn(4), multipleCurvesStartingWithRightTurn(5)} (0..255)
```

### <a name="HazardousLocation-SurfaceConditionSubCauseCode"></a>HazardousLocation-SurfaceConditionSubCauseCode

Encoded value of the sub cause codes of the event type `hazardousLocation-SurfaceCondition` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`     : in case further detailed information on the road surface condition is unavailable,
 - 1 `rockfalls`       : in case rock falls are detected on the road surface,
 - 2 `earthquakeDamage`: in case the road surface is damaged by earthquake,
 - 3 `sewerCollapse`   : in case of sewer collapse on the road surface,
 - 4 `subsidence`      : in case road surface is damaged by subsidence,
 - 5 `snowDrifts`      : in case road surface is damaged due to snow drift,
 - 6 `stormDamage`     : in case road surface is damaged by strong storm,
 - 7 `burstPipe`       : in case road surface is damaged due to pipe burst,
 - 8 `volcanoEruption` : in case road surface is damaged due to volcano eruption,
 - 9 `fallingIce`      : in case road surface damage is due to falling ice,
 - 10-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
HazardousLocation-SurfaceConditionSubCauseCode ::= INTEGER {unavailable(0), rockfalls(1), earthquakeDamage(2), sewerCollapse(3), subsidence(4), snowDrifts(5), stormDamage(6), burstPipe(7), volcanoEruption(8), fallingIce(9)} (0..255)
```

### <a name="HazardousLocation-ObstacleOnTheRoadSubCauseCode"></a>HazardousLocation-ObstacleOnTheRoadSubCauseCode

Encoded value of the sub cause codes of the event type `hazardousLocation-ObstacleOnTheRoad` as specified
 in clause A.10. Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`    : in case further detailed information on the detected obstacle is unavailable,
 - 1 `shedLoad`       : in case detected obstacle is large amount of obstacles (shedload),
 - 2 `partsOfVehicles`: in case detected obstacles are parts of vehicles,
 - 3 `partsOfTyres`   : in case the detected obstacles are parts of tyres,
 - 4 `bigObjects`     : in case the detected obstacles are big objects,
 - 5 `fallenTrees`    : in case the detected obstacles are fallen trees,
 - 6 `hubCaps`        : in case the detected obstacles are hub caps,
 - 7 `waitingVehicles`: in case the detected obstacles are waiting vehicles,
 - 8-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
HazardousLocation-ObstacleOnTheRoadSubCauseCode ::= INTEGER {unavailable(0), shedLoad(1), partsOfVehicles(2), partsOfTyres(3), bigObjects(4), fallenTrees(5), hubCaps(6), waitingVehicles(7)} (0..255)
```

### <a name="HazardousLocation-AnimalOnTheRoadSubCauseCode"></a>HazardousLocation-AnimalOnTheRoadSubCauseCode

Encoded value of the sub cause codes of the event type `hazardousLocation-AnimalOnTheRoad` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`  : in case further detailed information on the animal on the road event is unavailable,
 - 1 `wildAnimals`  : in case wild animals are detected on the road,
 - 2 `herdOfAnimals`: in case herd of animals are detected on the road,
 - 3 `smallAnimals` : in case small size animal is detected on the road,
 - 4 `largeAnimals` : in case large size animal is detected on the road,
 - 5-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
HazardousLocation-AnimalOnTheRoadSubCauseCode ::= INTEGER {unavailable(0), wildAnimals(1), herdOfAnimals(2), smallAnimals(3), largeAnimals(4)} (0..255)
```

### <a name="CollisionRiskSubCauseCode"></a>CollisionRiskSubCauseCode

Encoded value of the sub cause codes of the event type `collisionRisk` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`              : in case information on the type of collision risk is unavailable,
 - 1 `longitudinalCollisionRisk`: in case the type of detected collision risk is longitudinal collision risk,
                                  e.g. forward collision or face to face collision,
 - 2 `crossingCollisionRisk`    : in case the type of detected collision risk is crossing collision risk,
 - 3 `lateralCollisionRisk`     : in case the type of detected collision risk is lateral collision risk,
 - 4 `vulnerableRoadUser`       : in case the type of detected collision risk involves vulnerable road users
                                  e.g. pedestrians or bicycles,
 - 5-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
CollisionRiskSubCauseCode ::= INTEGER {unavailable(0), longitudinalCollisionRisk(1), crossingCollisionRisk(2), lateralCollisionRisk(3), vulnerableRoadUser(4)} (0..255)
```

### <a name="SignalViolationSubCauseCode"></a>SignalViolationSubCauseCode

Encoded value of the sub cause codes of the event type `signalViolation` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`               : in case further detailed information on signal violation event is unavailable,
 - 1 `stopSignViolation`         : in case a stop sign violation is detected,
 - 2 `trafficLightViolation`     : in case a traffic light violation is detected,
 - 3 `turningRegulationViolation`: in case a turning regulation violation is detected,
 - 4-255: reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
SignalViolationSubCauseCode ::= INTEGER {unavailable(0), stopSignViolation(1), trafficLightViolation(2), turningRegulationViolation(3)} (0..255)
```

### <a name="RescueAndRecoveryWorkInProgressSubCauseCode"></a>RescueAndRecoveryWorkInProgressSubCauseCode

Encoded value of the sub cause codes of the event type `rescueAndRecoveryWorkInProgress` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according
 to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`             : in case further detailed information on rescue and recovery work is unavailable,
 - 1 `emergencyVehicles`       : in case rescue work is ongoing by emergency vehicles,
 - 2 `rescueHelicopterLanding` : in case rescue helicopter is landing,
 - 3 `policeActivityOngoing`   : in case police activity is ongoing,
 - 4 `medicalEmergencyOngoing` : in case medical emergency recovery is ongoing,
 - 5 `childAbductionInProgress`: in case a child kidnapping alarm is activated and rescue work is ongoing,
 - 6-255: reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
RescueAndRecoveryWorkInProgressSubCauseCode ::= INTEGER {unavailable(0), emergencyVehicles(1), rescueHelicopterLanding(2), policeActivityOngoing(3), medicalEmergencyOngoing(4), childAbductionInProgress(5)} (0..255)
```

### <a name="DangerousEndOfQueueSubCauseCode"></a>DangerousEndOfQueueSubCauseCode

Encoded value of the sub cause codes of the event type `dangerousEndOfQueue` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according to clause 7.1.4 of ETSI ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`     : in case information on the type of dangerous queue is unavailable,
 - 1 `suddenEndOfQueue`: in case a sudden end of queue is detected, e.g. due to accident or obstacle,
 - 2 `queueOverHill`   : in case the dangerous end of queue is detected on the road hill,
 - 3 `queueAroundBend` : in case the dangerous end of queue is detected around the road bend,
 - 4 `queueInTunnel`   : in case queue is detected in tunnel,
 - 5-255 reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
DangerousEndOfQueueSubCauseCode ::= INTEGER {unavailable(0), suddenEndOfQueue(1), queueOverHill(2), queueAroundBend(3), queueInTunnel(4)} (0..255)
```

### <a name="DangerousSituationSubCauseCode"></a>DangerousSituationSubCauseCode

Encoded value of the sub cause codes of the event type `dangerousSituation` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according to clause 7.1.4 of ETSI ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`: in case information on the type of dangerous situation is unavailable,
 - 1 `emergencyElectronicBrakeEngaged`: in case emergency electronic brake is engaged,
 - 2 `preCrashSystemEngaged`: in case pre-crash system is engaged,
 - 3 `espEngaged`: in case Electronic Stability Program (ESP) system is engaged,
 - 4 `absEngaged`: in case Anti-lock braking system (ABS) is engaged,
 - 5 `aebEngaged`: in case Autonomous Emergency Braking (AEB) system is engaged,
 - 6 `brakeWarningEngaged`: in case brake warning is engaged,
 - 7 `collisionRiskWarningEngaged`: in case collision risk warning is engaged,
 - 8-255: reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
DangerousSituationSubCauseCode ::= INTEGER {unavailable(0), emergencyElectronicBrakeEngaged(1), preCrashSystemEngaged(2), espEngaged(3), absEngaged(4), aebEngaged(5), brakeWarningEngaged(6), collisionRiskWarningEngaged(7)} (0..255)
```

### <a name="VehicleBreakdownSubCauseCode"></a>VehicleBreakdownSubCauseCode

Encoded value of the sub cause codes of the event type `vehicleBreakdown` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`         : in case further detailed information on cause of vehicle break down is unavailable,
 - 1 `lackOfFuel`          : in case vehicle break down is due to lack of fuel,
 - 2 `lackOfBatteryPower`  : in case vehicle break down is caused by lack of battery power,
 - 3 `engineProblem`       : in case vehicle break down is caused by an engine problem,
 - 4 `transmissionProblem` : in case vehicle break down is caused by transmission problem,
 - 5 `engineCoolingProblem`: in case vehicle break down is caused by an engine cooling problem,
 - 6 `brakingSystemProblem`: in case vehicle break down is caused by a braking system problem,
 - 7 `steeringProblem`     : in case vehicle break down is caused by a steering problem,
 - 8 `tyrePuncture`        : in case vehicle break down is caused by tire puncture,
 - 9 `tyrePressureProblem` : in case low tyre pressure in detected,
 - 10-255: reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
VehicleBreakdownSubCauseCode ::= INTEGER {unavailable(0), lackOfFuel (1), lackOfBatteryPower (2), engineProblem(3), transmissionProblem(4), engineCoolingProblem(5), brakingSystemProblem(6), steeringProblem(7), tyrePuncture(8), tyrePressureProblem(9)} (0..255)
```

### <a name="PostCrashSubCauseCode"></a>PostCrashSubCauseCode

Encoded value of the sub cause codes of the event type `postCrash` as specified in clause A.10.
 Definition of the sub event cause is defined and the value is assigned according to clause 7.1.4 of ETSI EN 302 637-3 [i.3].

 The sub causes are described as following:
 - 0 `unavailable`: in case further detailed information on post crash event is unavailable,
 - 1 `accidentWithoutECallTriggered`: in case no eCall has been triggered for an accident,
 - 2 `accidentWithECallManuallyTriggered`: in case eCall has been manually triggered and transmitted to eCall back end,
 - 3 `accidentWithECallAutomaticallyTriggered`: in case eCall has been automatically triggered and transmitted to eCall back end,
 - 4 `accidentWithECallTriggeredWithoutAccessToCellularNetwork`: in case eCall has been triggered but cellular network is not accessible from triggering vehicle,
 - 5-255: reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
PostCrashSubCauseCode ::= INTEGER {unavailable(0), accidentWithoutECallTriggered (1), accidentWithECallManuallyTriggered (2), accidentWithECallAutomaticallyTriggered (3), accidentWithECallTriggeredWithoutAccessToCellularNetwork(4)} (0..255)
```

### <a name="Curvature"></a>Curvature

It describes the curvature of the vehicle trajectory and the accuracy.
 The curvature detected by a vehicle represents the curvature of actual vehicle trajectory.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

Fields:
* curvatureValue [**CurvatureValue**](#CurvatureValue) <br>
Detected curvature of the vehicle trajectory.
        It shall be presented as defined in clause A.15

* curvatureValue [**CurvatureValue**](#CurvatureValue) <br>
* curvatureConfidence [**CurvatureConfidence**](#CurvatureConfidence) <br>
Accuracy of the reported curvature value with a predefined confidence level.
        It shall be presented as defined in clause A.14

```asn1
Curvature ::= SEQUENCE {
 curvatureValue CurvatureValue,
 curvatureConfidence CurvatureConfidence
}
```

### <a name="CurvatureValue"></a>CurvatureValue

It describes vehicle turning curve with the following information:

     Value = 1 / Radius * 10000

 wherein radius is the vehicle turning curve radius.

 Positive values indicate a turning curve to the left hand side of the driver.
 It corresponds to the vehicle coordinate system as defined in ISO 8855 [2].
 - The value shall be set to `0` when the vehicle is moving straight.
 - The value shall be set to `1023`, if the information is not available.
 - For calculated values smaller than `-1023`, the DE shall be set to `-1023`.
 - For calculated values bigger than `1022`, the DE shall be set to `1022`.

 The DE is used in [**Curvature**](#Curvature) DF as defined in clause A.107.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The present DE is limited to vehicle types as defined in ISO 8855 [2].
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _1 over 10 000 metres_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
CurvatureValue ::= INTEGER {straight(0), unavailable(1023)} (-1023..1023)
```

### <a name="CurvatureConfidence"></a>CurvatureConfidence

It describes the absolute accuracy range of a reported curvature value for a predefined confidence level.
 The required confidence level is defined by the corresponding standards applying the DE.

 The value shall be set to:
 - 0 if the accuracy is less than or equal to 0,00002 m-1
 - 1 if the accuracy is less than or equal to 0,0001 m-1
 - 2 if the accuracy is less than or equal to 0,0005 m-1
 - 3 if the accuracy is less than or equal to 0,002 m-1
 - 4 if the accuracy is less than or equal to 0,01 m-1
 - 5 if the accuracy is less than or equal to 0,1 m-1
 - 6 if the accuracy is out of range, i.e. greater than 0,1 m-1
 - 7 if the information is not available

 The DE is used in Curvature DF as defined in clause A.107.
 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The fact that a curvature value is received with confidence set to `unavailable(7)` can be caused by
 several reasons, such as:
 - the sensor cannot deliver the accuracy at the defined confidence level because it is a low-end sensor,
 - the sensor cannot calculate the accuracy due to lack of variables, or
 - there has been a vehicle bus (e.g. CAN bus) error.
 In all 3 cases above, the reported curvature value may be valid and used by the application.
 If a curvature value is received and its confidence is set to 'outOfRange(6)', it means that the reported curvature value is not valid and therefore cannot be trusted. Such value is not useful for the application.
 {: .note}

```asn1
CurvatureConfidence ::= ENUMERATED {
    onePerMeter-0-00002 (0),
    onePerMeter-0-0001 (1),
    onePerMeter-0-0005 (2),
    onePerMeter-0-002 (3),
    onePerMeter-0-01 (4),
    onePerMeter-0-1 (5),
    outOfRange (6),
    unavailable (7)
}
```

### <a name="CurvatureCalculationMode"></a>CurvatureCalculationMode

It describes whether the yaw rate is used to calculate the curvature for a reported curvature value.

 When the information of curvature calculation mode is unknown, the value shall be set to 2.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
CurvatureCalculationMode ::= ENUMERATED {yawRateUsed(0), yawRateNotUsed(1), unavailable(2), ...}
```

### <a name="Heading"></a>Heading

Heading in a WGS84 co-ordinates system.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_ _[Vehicle information](#Vehicle+information)_ _[Road topology information](#Road+topology+information)_

Fields:
* headingValue [**HeadingValue**](#HeadingValue) <br>
a heading value. It shall be presented as defined in clause A.35,

* headingValue [**HeadingValue**](#HeadingValue) <br>
* headingConfidence [**HeadingConfidence**](#HeadingConfidence) <br>
the accuracy of the reported heading value with a predefined confidence level.
 It shall be presented as defined in clause A.34.

```asn1
Heading ::= SEQUENCE {
    headingValue HeadingValue,
    headingConfidence HeadingConfidence
}
```

### <a name="HeadingValue"></a>HeadingValue

Orientation of a heading with regards to the WGS84 north.

 When the information is not available, the DE shall be set to `3 601`.

 The DE is used in [**Heading**](#Heading) DF as defined in clause A.112, and [**PosConfidenceEllipse**](#PosConfidenceEllipse) DF as defined in clause A.119.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 degree_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_ _[Vehicle information](#Vehicle+information)_ _[Road topology information](#Road+topology+information)_

```asn1
HeadingValue ::= INTEGER {wgs84North(0), wgs84East(900), wgs84South(1800), wgs84West(2700), unavailable(3601)} (0..3601)
```

### <a name="HeadingConfidence"></a>HeadingConfidence

The absolute accuracy of a reported heading value for a predefined confidence level (e.g. 95 %).
 The required confidence level is defined by the corresponding standards applying the DE.

 The value shall be set to:
 - `1` if the heading accuracy is equal to or less than 0,1 degree,
 - `n (n > 1 and n < 125)` if the heading accuracy is equal to or less than n × 0,1 degree,
 - `125` if the heading accuracy is equal to or less than 12,5 degrees,
 - `126` if the heading accuracy is out of range, i.e. greater than 12,5 degrees,
 - `127` if the heading accuracy information is not available.

 The DE is used in Heading DF as defined in clause A.112.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The fact that a value is received with confidence set to `unavailable(127)` can be caused by several reasons,
 such as:
 - the sensor cannot deliver the accuracy at the defined confidence level because it is a low-end sensor,
 - the sensor cannot calculate the accuracy due to lack of variables, or
 - there has been a vehicle bus (e.g. CAN bus) error.
 In all 3 cases above, the reported heading value may be valid and used by the application.
 {: .note}


 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: If a heading value is received and its confidence is set to `outOfRange(126)`, it means that the reported
 heading value is not valid and therefore cannot be trusted. Such value is not useful for the application.
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 degree_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_ _[Vehicle information](#Vehicle+information)_ _[Road topology information](#Road+topology+information)_

```asn1
HeadingConfidence ::= INTEGER {equalOrWithinZeroPointOneDegree (1), equalOrWithinOneDegree (10), outOfRange(126), unavailable(127)} (1..127)
```

### <a name="LanePosition"></a>LanePosition

This DE indicates the transversal position information on the road in resolution of lanes, counted from
 the inside border of the road for a given traffic direction. For example, the innermostDrivingLane corresponds
 to the left most lane of the carriageway in a country with right-land traffic, and to the right most lane of the
 carriageway in a left-land traffic (e.g. in UK). The value -1 denotes that the referenced position is outside the road.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_ _[Road topology information](#Road+topology+information)_

```asn1
LanePosition ::= INTEGER {offTheRoad(-1), innerHardShoulder(0),
innermostDrivingLane(1), secondLaneFromInside(2), outerHardShoulder(14) } (-1..14)
```

### <a name="ClosedLanes"></a>ClosedLanes

This DF indicates the opening/closure status of a lane or a set of lanes.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_ _[Road topology information](#Road+topology+information)_

Fields:
* innerhardShoulderStatus [**HardShoulderStatus**](#HardShoulderStatus)  OPTIONAL<br>
this information is optional and shall be included if the information is known.
 It indicates the open/closing status of inner hard shoulder lanes. It shall be presented as defined in clause A.29

* innerhardShoulderStatus [**HardShoulderStatus**](#HardShoulderStatus)  OPTIONAL<br>
* outerhardShoulderStatus [**HardShoulderStatus**](#HardShoulderStatus)  OPTIONAL<br>
this information is optional and shall be included if the information is known.
 It indicates the open/closing status of outer hard shoulder lanes. It shall be presented as defined in clause A.29

* innerhardShoulderStatus [**HardShoulderStatus**](#HardShoulderStatus)  OPTIONAL<br>
* outerhardShoulderStatus [**HardShoulderStatus**](#HardShoulderStatus)  OPTIONAL<br>
* drivingLaneStatus [**DrivingLaneStatus**](#DrivingLaneStatus)  OPTIONAL<br>
this information is optional and shall be included if the information is known.
 It indicates the open/closing status of driving lanes. It shall be presented as defined in clause A.23
 For roads with more than 13 driving lanes, the drivingLaneStatus DE shall not be set.

```asn1
ClosedLanes ::= SEQUENCE {
    innerhardShoulderStatus HardShoulderStatus OPTIONAL,
    outerhardShoulderStatus HardShoulderStatus OPTIONAL,
    drivingLaneStatus DrivingLaneStatus OPTIONAL,
    ...
}
```

### <a name="HardShoulderStatus"></a>HardShoulderStatus

This DE indicates the current status of a hard shoulder lane whether it is available for special usage
 (e.g. for stopping or for driving) or closed for all vehicles.

 The DE is used in [**ClosedLanes**](#ClosedLanes) DF as defined in clause A.106.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
HardShoulderStatus ::= ENUMERATED {availableForStopping(0), closed(1), availableForDriving(2)}
```

### <a name="DrivingLaneStatus"></a>DrivingLaneStatus

DE that indicates whether a driving lane is open to traffic.

 A lane is counted from inside border of the road excluding the hardshoulder. The size of the bit string shall
 correspond to the total number of the driving lanes in the carriageway.

 The numbering is matched to [**LanePosition**](#LanePosition) DE as defined in clause A.40.
 The bit 0 is used to indicate the innermostLane, bit 1 is used to indicate the second lane from inside border.

 If a lane is closed to traffic, the corresponding bit shall be set to 1. Otherwise, it shall be set to 0.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: Hard shoulder status is not provided by this DE but in [**HardShoulderStatus**](#HardShoulderStatus) as defined in clause A.29.
 {: .note}


 The DE is used in [**ClosedLanes**](#ClosedLanes) DF as defined in clause A.106.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_ 

```asn1
DrivingLaneStatus ::= BIT STRING (SIZE (1..13))
```

### <a name="PerformanceClass"></a>PerformanceClass

This DE denotes the ability of an ITS-S to provide up-to-date information.
 A performance class value is used to describe age of data. The exact values are out of scope of the present document.

 As defined in ETSI TS 101 539-1 [i.6], performance class A shall be set to `1`, performance class B shall be set to 2.
 When the performance class is unknown, it shall be set to `0`.

 Values in the range `3 to 7` are reserved for future use.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
PerformanceClass ::= INTEGER {unavailable(0), performanceClassA(1), performanceClassB(2)} (0..7)
```

### <a name="SpeedValue"></a>SpeedValue

A speed value.
 - For values equal to or greater than `163,82 m/s`, the value shall be set to `16 382`.
 - When the information is not available, the value shall be set to `16 383`.

 The DE is used in [**Speed**](#Speed) DF as defined in clause A.126.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 m/s_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
SpeedValue ::= INTEGER {standstill(0), oneCentimeterPerSec(1), unavailable(16383)} (0..16383)
```

### <a name="SpeedConfidence"></a>SpeedConfidence

The absolute accuracy of a speed value information for a predefined confidence level.
 The required confidence level is defined by the station applying this DE.

 The value shall be set to:
 - `1` if the speed accuracy is equal to or less than `1 cm/s`.
 - `n (n > 1 and n < 125)` if the speed accuracy is equal to or less than `n cm/s`.
 - `125` if the speed accuracy is equal to or less than `125 cm/s`.
 - `126` if the speed accuracy is out of range, i.e. greater than `125 cm/s`.
 - `127` if the speed accuracy information is not available.

 The DE is used in [**Speed**](#Speed) DF as defined in clause A.126.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The fact that a speed value is received with confidence set to `unavailable(127)` can be caused by several reasons, such as:
 - the sensor cannot deliver the accuracy at the defined confidence level because it is a low-end sensor,
 - the sensor cannot calculate the accuracy due to lack of variables, or
 - there has been a vehicle bus (e.g. CAN bus) error.
 In all 3 cases above, the reported speed value may be valid and used by the application.
 {: .note}


 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: If a speed value is received and its confidence is set to `outOfRange(126)`, it means that the reported speed value is not valid and therefore cannot be trusted. Such is not useful for the application.
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _cm/s_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
SpeedConfidence ::= INTEGER {equalOrWithinOneCentimeterPerSec(1), equalOrWithinOneMeterPerSec(100), outOfRange(126), unavailable(127)} (1..127)
```

### <a name="VehicleMass"></a>VehicleMass

Mass of an empty loaded vehicle in multiple of 100 kg.
 - The value shall be set to `1 023` if the vehicle mass is equal to or greater than `102 300 kg`.
 - The value shall be set to `1 024` when the vehicle mass information is unavailable.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The empty load vehicle is defined in ISO 1176 [i.9], clause 4.6.
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _100kg_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
VehicleMass ::= INTEGER {hundredKg(1), unavailable(1024)} (1..1024)
```

### <a name="Speed"></a>Speed

Describes the speed and corresponding accuracy of the speed information for a moving object (e.g. vehicle).

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

Fields:
* speedValue [**SpeedValue**](#SpeedValue) <br>
speed value.
 It shall be presented as defined in clause A.74,

* speedValue [**SpeedValue**](#SpeedValue) <br>
* speedConfidence [**SpeedConfidence**](#SpeedConfidence) <br>
accuracy of the reported speed value.
 It shall be presented as defined in clause A.72.

```asn1
Speed ::= SEQUENCE {
    speedValue SpeedValue,
    speedConfidence SpeedConfidence
}
```

### <a name="DriveDirection"></a>DriveDirection

Denotes whether a vehicle is driving forward or backward.
 When the information is unavailable, the value shall be set to 2.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
DriveDirection ::= ENUMERATED {forward (0), backward (1), unavailable (2)}
```

### <a name="EmbarkationStatus"></a>EmbarkationStatus

Indicates whether a vehicle (e.g. public transport vehicle, truck) is under the embarkation process.
 If it is the case, the value shall be set to TRUE.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_ 

```asn1
EmbarkationStatus ::= BOOLEAN
```

### <a name="LongitudinalAcceleration"></a>LongitudinalAcceleration

It indicates the vehicle acceleration at longitudinal direction and the accuracy of the longitudinal acceleration.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

Fields:
* longitudinalAccelerationValue [**LongitudinalAccelerationValue**](#LongitudinalAccelerationValue) <br>
longitudinal acceleration value at a point in time.
 It shall be presented as specified in clause A.45,

* longitudinalAccelerationValue [**LongitudinalAccelerationValue**](#LongitudinalAccelerationValue) <br>
* longitudinalAccelerationConfidence [**AccelerationConfidence**](#AccelerationConfidence) <br>
accuracy of the reported longitudinal acceleration value with a predefined
 confidence level. It shall be presented as defined in clause A.1.

```asn1
LongitudinalAcceleration ::= SEQUENCE {
    longitudinalAccelerationValue LongitudinalAccelerationValue,
    longitudinalAccelerationConfidence AccelerationConfidence
}
```

### <a name="LongitudinalAccelerationValue"></a>LongitudinalAccelerationValue

Vehicle acceleration at longitudinal direction in the centre of the mass of the empty vehicle.
 It corresponds to the vehicle coordinate system as specified in ISO 8855 [2].
 - Negative values indicate that the vehicle is braking.
 - For values equal to or greater than 16 m/s2, the value shall be set to -160.
 - Positive values indicate that the vehicle is accelerating.
 - For acceleration equal to or greater than 16 m/s2 the value shall be set to 160.
 - When the data is unavailable, the value shall be set to 161.

 This acceleration is along the tangent plane of the road surface and does not include gravity components.

 The DE is used in [**LongitudinalAcceleration**](#LongitudinalAcceleration) DF as defined in clause A.116.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The empty load vehicle is defined in ISO 1176 [i.9], clause 4.6.
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
LongitudinalAccelerationValue ::= INTEGER {pointOneMeterPerSecSquaredForward(1), pointOneMeterPerSecSquaredBackward(-1), unavailable(161)} (-160 .. 161)
```

### <a name="AccelerationConfidence"></a>AccelerationConfidence

The absolute accuracy of a reported vehicle acceleration value with a predefined confidence level (e.g. 95 %). The required confidence level is defined by the corresponding standards applying the DE.

 The value shall be set to:
 - `1` if the acceleration accuracy is equal to or less than 0,1 m/s2.
 - `n (n > 1 and n < 100)` if the acceleration accuracy is equal to or less than n × 0,1 m/s2.
 - `100` if the acceleration accuracy is equal to or less than 10 m/s2.
 - `101` if the acceleration accuracy is out of range i.e. greater than 10 m/s2.
 - `102` if the data is unavailable.

 The DE is used in LateralAcceleration DF as defined in clause A.115, LongitudinalAcceleration DF as defined in clause A.116, or VerticalAcceleration DF as defined in clause A.129.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The fact that an acceleration value is received with confidence set to 'unavailable(102)' can be caused by several reasons, such as:
 - the sensor cannot deliver the accuracy at the defined confidence level because it is a low-end sensor,
 - the sensor cannot calculate the accuracy due to lack of variables, or
 - there has been a vehicle bus (e.g. CAN bus) error.
 {: .note}


 In all 3 cases above, the reported acceleration value may be valid and used by the application.

 If an acceleration value is received and its confidence is set to `outOfRange(101)`, it means that the value is not valid and therefore cannot be trusted. Such value is not useful for the application.
 @category Vehicle information

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 m/s2_

```asn1
AccelerationConfidence ::= INTEGER {pointOneMeterPerSecSquared(1), outOfRange(101), unavailable(102)} (0 .. 102)
```

### <a name="LateralAcceleration"></a>LateralAcceleration

Indicates the vehicle acceleration at lateral direction and the accuracy of the lateral acceleration.

 @field: lateralAccelerationValue: lateral acceleration value at a point in time.
 It shall be presented as specified in clause A.42,

 @field: lateralAccelerationConfidence: accuracy of the reported lateral acceleration value with
 a predefined confidence level. It shall be presented as defined in clause A.1.

 @category Vehicle information

```asn1
LateralAcceleration ::= SEQUENCE {
    lateralAccelerationValue LateralAccelerationValue,
    lateralAccelerationConfidence AccelerationConfidence
}
```

### <a name="LateralAccelerationValue"></a>LateralAccelerationValue

Vehicle acceleration at lateral direction in the centre of the mass of the empty vehicle.
 It corresponds to the vehicle coordinate system as specified in ISO 8855 [2].
 - Negative value indicates that the vehicle is accelerating towards the right side with regards to the vehicle orientation.
 - For values equal to or greater than 16 m/s2 towards the right, the value shall be set to -160.
 - Positive values indicate the acceleration to the left hand side with regards to the vehicle orientation.
 - For values equal to or greater than 16 m/s2 towards the left, the value shall be set to 160.
 - When the information is not available, the value shall be set to 161.

 The DE is used in [**LateralAcceleration**](#LateralAcceleration) DF as defined in clause A.115.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The empty load vehicle is defined in ISO 1176 [i.9], clause 4.6.
 {: .note}


 @category Vehicle information

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 m/s<sup>2</sup>_

```asn1
LateralAccelerationValue ::= INTEGER {pointOneMeterPerSecSquaredToRight(-1), pointOneMeterPerSecSquaredToLeft(1), unavailable(161)} (-160 .. 161)
```

### <a name="VerticalAcceleration"></a>VerticalAcceleration

It indicates the vehicle acceleration at vertical direction and the accuracy of the vertical acceleration.

 @field: verticalAccelerationValue: vertical acceleration value at a point in time.
 It shall be presented as specified in clause A.96,

 @field: verticalAccelerationConfidence: accuracy of the reported vertical acceleration value with
 a predefined confidence level. It shall be presented as defined in clause A.1.

 @category Vehicle information

```asn1
VerticalAcceleration ::= SEQUENCE {
    verticalAccelerationValue VerticalAccelerationValue,
    verticalAccelerationConfidence AccelerationConfidence
}
```

### <a name="VerticalAccelerationValue"></a>VerticalAccelerationValue

Vehicle acceleration at vertical direction in the centre of the mass of the empty vehicle.
 It corresponds to the vehicle coordinate system as specified in ISO 8855 [2].
 - Positive values indicate that the vehicle is accelerating upwards.
 - The value shall be set to `160` if the upwards acceleration is equal to or greater than 16 m/s<sup>2</sup>.-
 - Negative values indicate the vehicle is accelerating downwards.
 - The value shall be set to `-160` if the downwards acceleration is equal to or greater than 16 m/s<sup>2</sup>.
 - The value shall be set to `161` if the information is not available.

 The DE is used in [**VerticalAcceleration**](#VerticalAcceleration) DF as defined in clause A.129.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The empty load vehicle is defined in ISO 1176 [i.9], clause 4.6.
 {: .note}


 @category Vehicle information

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 m/s<sup>2</sup>_

```asn1
VerticalAccelerationValue ::= INTEGER {pointOneMeterPerSecSquaredUp(1), pointOneMeterPerSecSquaredDown(-1), unavailable(161)} (-160 .. 161)
```

### <a name="StationType"></a>StationType

The type of technical context the ITS-S is integrated in.
 The station type depends on the integration environment of ITS-S into vehicle, mobile devices or at infrastructure.

 The value shall be set to:
 - 0 `unknown`: information about the ITS-S context is not provided,
 - 1 pedestrian`: ITS-S carried by human being traveling on foot, incl. possible use of roller skates or skateboards,
 - 2 `cyclist`: ITS-S mounted on non-motorized unicycles, bicycles , tricycles, quadracycles,
 - 3 `moped`: ITS-S mounted on light motor vehicles with less than four wheels as defined in UNECE/TRANS/WP.29/78/Rev.4 [i.18] class L1, L2,
 - 4 `motorcycles`: ITS-S mounted on motor vehicles with less than four wheels as defined in UNECE/TRANS/WP.29/78/Rev.4 [i.18] class L3, L4, L5, L6, L7,
 - 5 `passengerCar`: ITS-S mounted on small passenger vehicles as defined in UNECE/TRANS/WP.29/78/Rev.4 [i.18] class M1,
 - 6 `bus`: ITS-S mounted on large passenger vehicles as defined in UNECE/TRANS/WP.29/78/Rev.4 [i.18] class M2, M3,
 - 7 `lightTruck`: ITS-S mounted on light Goods Vehicles as defined in UNECE/TRANS/WP.29/78/Rev.4 [i.18] class N1,
 - 8 `heavyTruck`: ITS-S mounted on Heavy Goods Vehicles as defined in UNECE/TRANS/WP.29/78/Rev.4 [i.18] class N2 and N3,
 - 9 `trailer`: ITS-S mounted on an unpowered vehicle that is intended to be towed by a powered vehicle as defined in UNECE/TRANS/WP.29/78/Rev.4 [i.18] class O,
   ***NOTE***: Only to be used when not towed.
 - 10 `specialVehicles`: ITS-S mounted on vehicles which have special purposes other than the above (e.g. moving road works vehicle),
 - 11 `tram`: ITS-S mounted on a vehicle which runs on tracks along public streets,
 - 12 `roadSideUnit`: ITS-S mounted on an infrastructure typically positioned outside of the drivable roadway (e.g. on a gantry, on a pole, on a stationary road works trailer); the infrastructure is static during the entire operation period of the ITS-S (e.g. no stop and go activity),
 - 13 16-255: reserved for future usage.

 The DE is used in [**RestrictedTypes**](#RestrictedTypes) DF as defined in clause A.125.

 @category Vehicle information

```asn1
StationType ::= INTEGER {unknown(0), pedestrian(1), cyclist(2), moped(3), motorcycle(4), passengerCar(5), bus(6), 
lightTruck(7), heavyTruck(8), trailer(9), specialVehicles(10), tram(11), roadSideUnit(15)} (0..255)
```

### <a name="ExteriorLights"></a>ExteriorLights

This DE describes the status of the exterior light switches of a vehicle.

 The value of each bit indicates the state of the switch, which commands the corresponding light.
 The bit corresponding to a specific light is set to `1`, when the corresponding switch is turned on,
 either manually by the driver or automatically by a vehicle system. The bit value does not indicate
 if the corresponding lamps are alight or not.

 If a vehicle is not equipped with a certain light or if the light switch status information is not available,
 the corresponding bit shall be set to `0`.

 The `fogLightOn` only indicates the status of the tail fog lamp switch.

 As the bit value indicates only the state of the switch, the turn signal and hazard signal bit values shall not
 alternate with the blinking interval.

 For hazard indicator, the `leftTurnSignalOn` (2) and `rightTurnSignalOn` (3) shall be both set to 1.

 @category Vehicle information

```asn1
ExteriorLights ::= BIT STRING {
    lowBeamHeadlightsOn      (0),
    highBeamHeadlightsOn     (1),
    leftTurnSignalOn         (2),
    rightTurnSignalOn        (3),
    daytimeRunningLightsOn   (4),
    reverseLightOn           (5),
    fogLightOn               (6),
    parkingLightsOn          (7)
} (SIZE(8))
```

### <a name="DangerousGoodsBasic"></a>DangerousGoodsBasic

This DE indicates the type of the dangerous goods being carried by a heavy vehicle.
 The value is assigned according to "_class_" and "_division_" definitions of dangerous goods as specified in part II,
 chapter 2.1.1.1 of European Agreement concerning the International Carriage of Dangerous Goods by Road [i.4].

 The DE is used in [**DangerousGoodsExtended**](#DangerousGoodsExtended) DF as defined in clause A.108.

 @category Vehicle information

```asn1
DangerousGoodsBasic::= ENUMERATED {
    explosives1(0),
    explosives2(1),
    explosives3(2),
    explosives4(3),
    explosives5(4),
    explosives6(5),
    flammableGases(6),
    nonFlammableGases(7),
    toxicGases(8),
    flammableLiquids(9),
    flammableSolids(10),
    substancesLiableToSpontaneousCombustion(11),
    substancesEmittingFlammableGasesUponContactWithWater(12),
    oxidizingSubstances(13),
    organicPeroxides(14),
    toxicSubstances(15),
    infectiousSubstances(16),
    radioactiveMaterial(17),
    corrosiveSubstances(18),
    miscellaneousDangerousSubstances(19)
}
```

### <a name="DangerousGoodsExtended"></a>DangerousGoodsExtended

This DF provides a description of dangerous goods being carried by a heavy vehicle.

 @category Vehicle information

Fields:
* dangerousGoodsType [**DangerousGoodsBasic**](#DangerousGoodsBasic) <br>
Type of dangerous goods, It shall be presented as defined in clause A.17,

* unNumber **INTEGER**  (0..9999)<br>
a 4-digit number that identifies the substance of the dangerous goods as specified in
 United Nations Recommendations on the Transport of Dangerous Goods - Model Regulations [i.5],

* elevatedTemperature **BOOLEAN** <br>
whether the carried dangerous goods are transported at high temperature.
 If yes, the value shall be set to TRUE,

* tunnelsRestricted **BOOLEAN** <br>
whether the heavy vehicle carrying dangerous goods is restricted to enter tunnels.
 If yes, the value shall be set to TRUE,

* limitedQuantity **BOOLEAN** <br>
whether the carried dangerous goods are packed with limited quantity.
 If yes, the value shall be set to TRUE,

* limitedQuantity **BOOLEAN** <br>
* emergencyActionCode [**IA5String**](#IA5String)  (SIZE (1..24)) OPTIONAL<br>
physical signage placard at the vehicle that carries information on how an emergency
 service should deal with an incident. This DE is optional; it shall be present if the information is available,

* limitedQuantity **BOOLEAN** <br>
* emergencyActionCode [**IA5String**](#IA5String)  (SIZE (1..24)) OPTIONAL<br>
* phoneNumber [**PhoneNumber**](#PhoneNumber)  OPTIONAL<br>
contact phone number of assistance service in case of incident or accident.
 This DE is optional, it shall be present if the information is available.
 It shall be presented as defined in clause A.135,

* limitedQuantity **BOOLEAN** <br>
* emergencyActionCode [**IA5String**](#IA5String)  (SIZE (1..24)) OPTIONAL<br>
* phoneNumber [**PhoneNumber**](#PhoneNumber)  OPTIONAL<br>
* companyName [**UTF8String**](#UTF8String)  (SIZE (1..24)) OPTIONAL<br>
name of company that manages the transportation of the dangerous goods.
 This DE is optional; it shall be present if the information is available.

```asn1
DangerousGoodsExtended ::= SEQUENCE {
    dangerousGoodsType DangerousGoodsBasic,
    unNumber INTEGER (0..9999),
    elevatedTemperature BOOLEAN,
    tunnelsRestricted BOOLEAN,
    limitedQuantity BOOLEAN,
    emergencyActionCode IA5String (SIZE (1..24)) OPTIONAL,
    phoneNumber PhoneNumber OPTIONAL,
    companyName UTF8String (SIZE (1..24)) OPTIONAL,
        ...
}
```

### <a name="SpecialTransportType"></a>SpecialTransportType

It indicates if a vehicle is carrying goods with heavy load, excess width, excess length or excess height.
 The corresponding bit shall be set to 1 when the special transport applies to the corresponding case.
 Otherwise, the corresponding bit shall be set to 0.

 @category Vehicle information

```asn1
SpecialTransportType ::= BIT STRING {heavyLoad(0), excessWidth(1), excessLength(2), excessHeight(3)} (SIZE(4))
```

### <a name="LightBarSirenInUse"></a>LightBarSirenInUse

It describes the status of light bar and any sort of audible alarm system besides the horn.
 This includes various common sirens as well as backup up beepers and other slow speed manoeuvring alerts.
 When the light bar or audible alarm is active, the corresponding bits shall be set to 1.
 Otherwise, it shall be set to 0.

 @category Vehicle information

```asn1
LightBarSirenInUse ::= BIT STRING {
    lightBarActivated (0),
    sirenActivated (1)
} (SIZE(2))
```

### <a name="HeightLonCarr"></a>HeightLonCarr

Height of left or right longitude carrier of vehicle from base to top (left or right carrier seen from vehicle
 rear to front). For values equal to or greater than 99 cm, the DE shall be set to 99.
 If the value is unavailable, the DE shall be set to 100.
 @category Vehicle information

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _1 centimeter_

```asn1
HeightLonCarr ::= INTEGER {oneCentimeter(1), unavailable(100)} (1..100)
```

### <a name="PosLonCarr"></a>PosLonCarr

Distance from the centre of vehicle front bumper to the right or left longitudinal carrier of vehicle.
 The left/right carrier refers to the left/right as seen from a passenger sitting in the vehicle.
 For values equal to or higher than 1.26 metres, the value shall be set to `126`.
 If the information is unavailable, the value shall be set to `127`.
 @category Vehicle information

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _1 centimeter_

```asn1
PosLonCarr ::= INTEGER {oneCentimeter(1), unavailable(127)} (1..127)
```

### <a name="PosPillar"></a>PosPillar

It indicates the perpendicular inter-distance of neighbouring pillar axis of vehicle starting from the
 middle point of the front line of the vehicle bounding box.
 For values equal to or greater than 2.9 metres, the value shall be set to `29`.
 The value shall be set to `30` if the information is unavailable.

 The DE is used in [**PositionOfPillars**](#PositionOfPillars) DF as defined in clause A.120.
 @category Vehicle information

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _1 centimeter_

```asn1
PosPillar ::= INTEGER {tenCentimeters(1), unavailable(30)} (1..30)
```

### <a name="PosCentMass"></a>PosCentMass

It indicates the perpendicular distance from the centre of mass of an empty load vehicle to the front line of
 the vehicle bounding box of the empty load vehicle.
 For values equal to or higher than 6.2 metres, the data value be set to `62`.
 The value shall be set to `63` if the information is unavailable.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The empty load vehicle is defined in ISO 1176 [i.9], clause 4.6.
 @category Vehicle information
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _1 centimeter_

```asn1
PosCentMass ::= INTEGER {tenCentimeters(1), unavailable(63)} (1..63)
```

### <a name="RequestResponseIndication"></a>RequestResponseIndication

This DE includes whether an ITS message is transmitted as request from ITS-S or a response transmitted from
 ITS-S after receiving request from other ITS-Ss.
 @category Communication information

```asn1
RequestResponseIndication ::= ENUMERATED {request(0), response(1)}
```

### <a name="SpeedLimit"></a>SpeedLimit

Speed limitation applied to a geographical position, a road section or a geographical region.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _km/h_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Infrastructure information](#Infrastructure+information)_ _[Traffic information](#Traffic+information)_

```asn1
SpeedLimit ::= INTEGER {oneKmPerHour(1)} (1..255)
```

### <a name="StationarySince"></a>StationarySince

It indicates the duration in minutes of a vehicle being stationary.
 For a vehicle being stationary since equal to or greater than 15 minutes, the value shall be set to `3`.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Infrastructure information](#Infrastructure+information)_ _[Traffic information](#Traffic+information)_

```asn1
StationarySince ::= ENUMERATED {lessThan1Minute(0), lessThan2Minutes(1), lessThan15Minutes(2), equalOrGreater15Minutes(3)}
```

### <a name="Temperature"></a>Temperature

Temperature.
 - For temperature equal to or less than -60 °C, the value shall be set to  `60`.
 - For temperature equal to or greater than 67 °C, the value shall be set to `67`.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _°C_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Other information](#Other+information)_

```asn1
Temperature ::= INTEGER {equalOrSmallerThanMinus60Deg (-60), oneDegreeCelsius(1), equalOrGreaterThan67Deg(67)} (-60..67)
```

### <a name="TrafficRule"></a>TrafficRule

It indicates traffic rules that apply to vehicles at a certain position.
 It includes the following information:
 - If overtaking is prohibited for all vehicles, the DE shall be set to `0`.
 - If overtaking is prohibited for trucks, the DE shall be set to `1`.
 - If vehicles should pass to the right lane, the DE shall be set to `2`.
 - If vehicles should pass to the left lane, the DE shall be set to `3`.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Infrastructure information](#Infrastructure+information)_ _[Traffic information](#Traffic+information)_

```asn1
TrafficRule ::= ENUMERATED {noPassing(0), noPassingForTrucks(1), passToRight(2), passToLeft(3), ...
}
```

### <a name="WheelBaseVehicle"></a>WheelBaseVehicle

Perpendicular distance between front and rear axle of the wheel base of vehicle.
 - The value shall be set to `126` if the wheel base distance is equal to or greater than 12.6 metres.
 - The value shall be set to `127` if the information is unavailable.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 metre_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
WheelBaseVehicle ::= INTEGER {tenCentimeters(1), unavailable(127)} (1..127)
```

### <a name="TurningRadius"></a>TurningRadius

The smallest circular turn (i.e. U-turn) that the vehicle is capable of making.
 - The value shall be set to `254` if the turning radius is equal to or greater than 254 × 0.4 metre = 101.6 metres.
 - The value shall be set to `255` if the information is unavailable.

 For vehicle with tracker, the turning radius applies to the vehicle only.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.4 metre_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
TurningRadius ::= INTEGER {point4Meters(1), unavailable(255)} (1..255)
```

### <a name="PosFrontAx"></a>PosFrontAx

Perpendicular distance between the vehicle front line of the bounding box and the front wheel axle in 10 centimetres.
 - For values equal to or higher than 1.9 metres, the DE shall be set to `19`.
 - The value shall bet set to `20` if the information is unavailable.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 metre_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
PosFrontAx ::= INTEGER {tenCentimeters(1), unavailable(20)} (1..20)
```

### <a name="PositionOfOccupants"></a>PositionOfOccupants

It indicates whether a passenger seat is occupied or whether the occupation status is detectable or not.

 The number of row in vehicle seats layout is counted in rows from the driver row backwards from front to the rear
 of the vehicle.
 The left side seat of a row refers to the left hand side seen from vehicle rear to front.
 Additionally, a bit is reserved for each seat row, to indicate if the seat occupation of a row is detectable or not,
 i.e. `row1NotDetectable (3)`, `row2NotDetectable(8)`, `row3NotDetectable(13)` and `row4NotDetectable(18)`.
 Finally, a bit is reserved for each row seat to indicate if the seat row is present or not in the vehicle,
 i.e. row1NotPresent `(4)`, row2NotPresent `(9)`, `row3NotPresent(14)`, `row4NotPresent(19)`.

 When a seat is detected to be occupied, the corresponding seat occupation bit shall be set to `1`.
 For example, when the row 1 left seat is occupied, `row1LeftOccupied(0)` bit shall be set to 1.
 When a seat is detected to be not occupied, the corresponding seat occupation bit shall be set to `0`.
 Otherwise, the value of seat occupation bit shall be set according to the following conditions:
 - If the seat occupation of a seat row is not detectable, the corresponding bit shall be set to `1`.
   When any seat row not detectable bit is set to `1`, all corresponding seat occupation bits of the same row
   shall be set to `1`.
 - If the seat row is not present, the corresponding not present bit of the same row shall be set to `1`.
   When any of the seat row not present bit is set to `1`, the corresponding not detectable bit for that row
   shall be set to `1`, and all the corresponding seat occupation bits in that row shall be set to `0`.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
PositionOfOccupants ::= BIT STRING {
    row1LeftOccupied (0),
    row1RightOccupied (1),
    row1MidOccupied (2),
    row1NotDetectable (3),
    row1NotPresent (4),
    row2LeftOccupied (5),
    row2RightOccupied (6),
    row2MidOccupied (7),
    row2NotDetectable (8),
    row2NotPresent (9),
    row3LeftOccupied (10),
    row3RightOccupied (11),
    row3MidOccupied (12),
    row3NotDetectable (13),
    row3NotPresent (14),
    row4LeftOccupied (15),
    row4RightOccupied (16),
    row4MidOccupied (17),
    row4NotDetectable (18),
    row4NotPresent (19)} (SIZE(20))
```

### <a name="PositioningSolutionType"></a>PositioningSolutionType

It indicates the positioning technology being used to estimate a geographical position.
 It covers the following positioning solutions:
 - 1 `sGNSS`: Global Navigation Satellite System,
 - 2 `dGNSS`: Differential GNSS,
 - 3 `sGNSSplusDR`: GNSS and dead reckoning,
 - 4 `dGNSSplusDR`: Differential GNSS and dead reckoning,
 - 5 `dR`: dead reckoning.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

```asn1
PositioningSolutionType ::= ENUMERATED {noPositioningSolution(0), sGNSS(1), dGNSS(2), sGNSSplusDR(3), dGNSSplusDR(4), dR(5), ...}
```

### <a name="VehicleIdentification"></a>VehicleIdentification

This DF provides information related to the identification of a vehicle.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

Fields:
* wMInumber [**WMInumber**](#WMInumber)  OPTIONAL<br>
World Manufacturer Identifier (WMI) code. It shall be presented as defined in clause A.98,

* wMInumber [**WMInumber**](#WMInumber)  OPTIONAL<br>
* vDS [**VDS**](#VDS)  OPTIONAL<br>
Vehicle Descriptor Section (VDS). It shall be presented as defined in clause A.89.

```asn1
VehicleIdentification ::= SEQUENCE {
    wMInumber WMInumber OPTIONAL,
    vDS VDS OPTIONAL,
    ...
}
```

### <a name="WMInumber"></a>WMInumber

World Manufacturer Identifier (WMI). The values are assigned according to ISO 3779 [i.7].

 The DE is used in [**VehicleIdentification**](#VehicleIdentification) DF as defined in clause A.130.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_ 

```asn1
WMInumber ::= IA5String (SIZE(1..3))
```

### <a name="VDS"></a>VDS

Vehicle Descriptor Section (VDS). The values are assigned according to ISO 3779 [i.7].

 The DE is used in [**VehicleIdentification**](#VehicleIdentification) DF as defined in clause A.130.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_ 

```asn1
VDS ::= IA5String (SIZE(6))
```

### <a name="EnergyStorageType"></a>EnergyStorageType

Type of energy being used and stored in vehicle.
 - If a storage type is used by the vehicle, the corresponding bit shall be set to `1`.
 - Otherwise, the corresponding bit shall be set to `0`.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
EnergyStorageType ::= BIT STRING {hydrogenStorage(0), electricEnergyStorage(1), liquidPropaneGas(2), compressedNaturalGas(3), diesel(4), gasoline(5), ammonia(6)} (SIZE(7))
```

### <a name="VehicleLength"></a>VehicleLength

Length of vehicle and accuracy indication information.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

Fields:
* vehicleLengthValue [**VehicleLengthValue**](#VehicleLengthValue) <br>
length of vehicle. It shall be presented as defined in clause A.92

* vehicleLengthValue [**VehicleLengthValue**](#VehicleLengthValue) <br>
* vehicleLengthConfidenceIndication [**VehicleLengthConfidenceIndication**](#VehicleLengthConfidenceIndication) <br>
indication of reported length value confidence.
 It shall be presented as defined in clause A.91.

```asn1
VehicleLength ::= SEQUENCE {
    vehicleLengthValue VehicleLengthValue,
    vehicleLengthConfidenceIndication VehicleLengthConfidenceIndication
}
```

### <a name="VehicleLengthValue"></a>VehicleLengthValue

Length of a vehicle.
 - The value shall be set to 1 022 if the vehicle length is equal to or greater than 102.2 metres.
 - The value shall be set to 1 023 if the information in unavailable.

 The DE is used in [**VehicleLength**](#VehicleLength) DF as defined in clause A.131.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 metre_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
VehicleLengthValue ::= INTEGER {tenCentimeters(1), outOfRange(1022), unavailable(1023)}  (1..1023)
```

### <a name="VehicleLengthConfidenceIndication"></a>VehicleLengthConfidenceIndication

To indicate whether the presence of a trailer is detectable or whether its length is included in a
 reported vehicle length value.
 - When the information is not known, the value shall be set to `unavailable(4)`.

 The DE is used in [**VehicleLength**](#VehicleLength) DF as defined in clause A.131.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
VehicleLengthConfidenceIndication ::= ENUMERATED {noTrailerPresent(0), trailerPresentWithKnownLength(1), trailerPresentWithUnknownLength(2), trailerPresenceIsUnknown(3), unavailable(4)}
```

### <a name="VehicleWidth"></a>VehicleWidth

Width of a vehicle, including side mirrors.
 - For a vehicle width equal to or greater than 6.1 metres, the value shall be set to `61`.
 - The value shall be set to `62` if the information is unavailable.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0.1 metre_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_

```asn1
VehicleWidth ::= INTEGER {tenCentimeters(1), outOfRange(61), unavailable(62)} (1..62)
```

### <a name="PathHistory"></a>PathHistory

DF that defines a path with a set of path points.
 It may contain up to `40` path points. Each path point shall be presented as defined in clause A.118 [**PathPoint**](#PathPoint).

 It may be used to describe the historical path of a vehicle.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_ _[Vehicle information](#Vehicle+information)_ 

```asn1
PathHistory::= SEQUENCE (SIZE(0..40)) OF PathPoint
```

### <a name="EmergencyPriority"></a>EmergencyPriority

It indicates the right of priority requested by an operating emergency vehicle.
 The right-of-priority bit shall be set to 1 if the corresponding right is requested.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
EmergencyPriority ::= BIT STRING {requestForRightOfWay(0), requestForFreeCrossingAtATrafficLight(1)} (SIZE(2))
```

### <a name="InformationQuality"></a>InformationQuality

Quality level of provided information.

 The DE is used in [**EventPoint**](#EventPoint) DF as defined in clause A.111.

  &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: Definition of quality level is out of scope of the present document.
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Other information](#Other+information)_

```asn1
InformationQuality ::= INTEGER {unavailable(0), lowest(1), highest(7)} (0..7)
```

### <a name="RoadType"></a>RoadType

Type of a road segment.

  > NOTE: Definition of road type is out of scope of the present document.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Road Topology Information](#Road+Topology+Information)_

```asn1
RoadType ::= ENUMERATED {
    urban-NoStructuralSeparationToOppositeLanes(0),
    urban-WithStructuralSeparationToOppositeLanes(1),
    nonUrban-NoStructuralSeparationToOppositeLanes(2),
    nonUrban-WithStructuralSeparationToOppositeLanes(3)}
```

### <a name="SteeringWheelAngle"></a>SteeringWheelAngle

Steering wheel angle of the vehicle at certain point in time.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle Information](#Vehicle+Information)_

Fields:
* steeringWheelAngleValue [**SteeringWheelAngleValue**](#SteeringWheelAngleValue) <br>
steering wheel angle value. It shall be presented as defined in clause A.80,

* steeringWheelAngleValue [**SteeringWheelAngleValue**](#SteeringWheelAngleValue) <br>
* steeringWheelAngleConfidence [**SteeringWheelAngleConfidence**](#SteeringWheelAngleConfidence) <br>
accuracy of the reported steering wheel angle value.
 It shall be presented as defined in clause A.79.

```asn1
SteeringWheelAngle ::= SEQUENCE {
    steeringWheelAngleValue SteeringWheelAngleValue,
    steeringWheelAngleConfidence SteeringWheelAngleConfidence
}
```

### <a name="SteeringWheelAngleValue"></a>SteeringWheelAngleValue

Steering wheel angle of the vehicle at certain point in time.
 It corresponds to the vehicle coordinate system as specified in ISO 8855 [2].
 - Positive values indicate that the steering wheel angle is turning counter-clockwise (i.e. to the left).
 - Negative values shall be used when the steering wheel angle is turning clockwise (i.e. to the right).
 - The value shall be set to `511` if the steering wheel angle is equal to or greater than 511 × 1,5 degrees = 766,5 degrees to the left.
 - The value shall be set to `-511` if the steering wheel angle is equal to or greater than 511 × 1,5 degrees = 766,5 degrees to the right.
 - When the information is not available, the value shall be set to `512`.

 The DE is used in [**SteeringWheelAngle**](#SteeringWheelAngle) DF as defined in clause A.127.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _1.5 degree_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle Information](#Vehicle+Information)_

```asn1
SteeringWheelAngleValue ::= INTEGER {straight(0), onePointFiveDegreesToRight(-1), onePointFiveDegreesToLeft(1), unavailable(512)} (-511..512)
```

### <a name="SteeringWheelAngleConfidence"></a>SteeringWheelAngleConfidence

Absolute accuracy for a reported steering wheel angle value for a predefined confidence level (e.g. 95 %).
 The required confidence level is defined by the station applying this DE.

 The value shall be set to:
 - `1` if the steering wheel angle accuracy is equal to or less than 1,5 degrees,
 - `n (n > 1 and n < 125)` if the steering wheel angle accuracy is equal to or less than n × 1,5 degrees,
 - `125` if the steering wheel angle accuracy is equal to or less than 1,5 degrees ×125 = 187,5 degrees,
 - `126` if the accuracy is out of range, i.e. greater than 187,5 degrees,
 - `127` if the accuracy information is not available.

 The DE is used in [**SteeringWheelAngle**](#SteeringWheelAngle) DF as defined in clause A.127.
 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE1**: The fact that a steering wheel angle value is received with confidence set to 'unavailable(127)'
 can be caused by several reasons, such as:
 - the sensor cannot deliver the accuracy at the defined confidence level because it is a low-end sensor,
 - the sensor cannot calculate the accuracy due to lack of variables, or
 - there has been a vehicle bus (e.g. CAN bus) error.
 In all 3 cases above, the reported steering wheel angle value may be valid and used by the application.
 {: .note}


 If a steering wheel angle value is received and its confidence is set to 'outOfRange(126)',
 it means that the reported steering wheel angle value is not valid and therefore cannot be trusted.
 Such value is not useful for the application.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _1.5 degree_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle Information](#Vehicle+Information)_

```asn1
SteeringWheelAngleConfidence ::= INTEGER {equalOrWithinOnePointFiveDegree (1), outOfRange(126), unavailable(127)} (1..127)
```

### <a name="TimestampIts"></a>TimestampIts

Number of milliseconds since `2004-01-01T00:00:00.000Z`, as specified in ISO 8601 [i.10].

 EXAMPLE:	The value for TimestampIts for `2007-01-01T00:00:00.000Z` is `94 694 401 000` milliseconds,
 which includes one leap second insertion since `2004-01-01T00:00:00.000Z`.

 The DE is used in [**ProtectedCommunicationZone**](#ProtectedCommunicationZone) DF as defined in clause A.121.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _millisecond_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Other Information](#Other+Information)_

```asn1
TimestampIts ::= INTEGER {utcStartOf2004(0), oneMillisecAfterUTCStartOf2004(1)} (0..4398046511103)
```

### <a name="VehicleRole"></a>VehicleRole

Role played by a vehicle at a point in time.
 The DE shall be set to:
 - 0 `default`: default vehicle role as indicated by the vehicle type,
 - 1 `publicTransport`: vehicle is used to operate public transport service,
 - 2 `specialTransport`: vehicle is used for special transport purpose, e.g. oversized trucks,
 - 3 `dangerousGoods`: vehicle is used for dangerous goods transportation,
 - 4 `roadWork`: vehicle is used to realize roadwork or road maintenance mission,
 - 5 `rescue`: vehicle is used for rescue purpose in case of an accident, e.g. as a towing service,
 - 6 `emergency`: vehicle is used for emergency mission, e.g. ambulance, fire brigade,
 - 7 `safetyCar`: vehicle is used for public safety, e.g. patrol,
 - 8 `agriculture`: vehicle is used for agriculture, e.g. farm tractor as defined
   in CEN/TS 16157-3 [3], annex A, table A.137,
 - 9 `commercial`: vehicle is used for transportation of commercial goods as defined
   in CEN/TS 16157-3 [3], annex A, table A.137,
 - 10 `military`: vehicle is used for military purpose as defined in CEN/TS 16157-3 [3], annex A, table A.137,
 - 11 `roadOperator`: vehicle is used in road operator missions as defined in CEN/TS 16157-3 [3], annex A, table A.137,
 - 12 `taxi`: vehicle is used to provide an authorized taxi service as defined
   in CEN/TS 16157-3 [3], annex A, table A.137,
 - 13 `reserved`: reserved for future usage,
 - 14 `reserved`: reserved for future usage,
 - 15 `reserved`: reserved for future usage.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle Information](#Vehicle+Information)_

```asn1
VehicleRole ::= ENUMERATED {default(0), publicTransport(1), specialTransport(2), dangerousGoods(3), roadWork(4), rescue(5), emergency(6), safetyCar(7), agriculture(8), commercial(9), military(10), roadOperator(11), taxi(12), reserved1(13), reserved2(14), reserved3(15)}
```

### <a name="YawRate"></a>YawRate

Yaw rate of vehicle at a point in time.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle Information](#Vehicle+Information)_

Fields:
* yawRateValue [**YawRateValue**](#YawRateValue) <br>
yaw rate value at a point in time. It shall be presented as defined in clause A.101,

```asn1
YawRate::= SEQUENCE {
    yawRateValue YawRateValue,
    yawRateConfidence YawRateConfidence
}
```

### <a name="YawRateValue"></a>YawRateValue

It denotes the vehicle rotation around z-axis of coordinate system centred on the centre of mass of the empty-loaded
 vehicle. It corresponds to the vehicle coordinate system as specified in ISO 8855 [2].
 - The leading sign denotes the direction of rotation.
 - Positive values indicate that the rotation is anti-clockwise (i.e. to the left).
 - The value shall be set to `32 766` if the yaw rate is equal to or greater than 327.66 degrees/second to the left.
 - Negative values indicate that the rotation is clockwise (i.e. to the right).
 - The value shall be set to `-32 766` if the yaw rate is equal to or greater than 327,66 degrees/second to the right.
 - The value shall be set to `32 767` if the information is not available.

 The yaw rate value shall be a raw data value, i.e. not filtered, smoothed or otherwise modified.
 The reading instant should be the same as for the vehicle acceleration.

 The DE is used in [**YawRate**](#YawRate) DF as defined in clause A.132.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: The empty load vehicle is defined in ISO 1176 [i.9], clause 4.6.
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle Information](#Vehicle+Information)_

```asn1
YawRateValue ::= INTEGER {straight(0), degSec-000-01ToRight(-1), degSec-000-01ToLeft(1), unavailable(32767)} (-32766..32767)
```

### <a name="YawRateConfidence"></a>YawRateConfidence

DE that denotes the absolute accuracy range for reported yaw rate value for a predefined confidence level (e.g. 95 %).
 The required confidence level is defined by the station applying this DE.

 The value shall be set to:
 - 0 if the accuracy is equal to or less than 0,01 degree/second
 - 1 if the accuracy is equal to or less than 0,05 degrees/second
 - 2 if the accuracy is equal to or less than 0,1 degree/second
 - 3 if the accuracy is equal to or less than 1 degree/second
 - 4 if the accuracy is equal to or less than 5 degrees/second
 - 5 if the accuracy is equal to or less than 10 degrees/second
 - 6 if the accuracy is equal to or less than 100 degrees/second
 - 7 if the accuracy is out of range, i.e. greater than 100 degrees/second
 - 8 if the accuracy information is unavailable

 The DE is used in [**YawRate**](#YawRate) DF as defined in clause A.132.

 NOTE:	The fact that a yaw rate value is received with confidence set to `unavailable(8)` can be caused by
 several reasons, such as:
 - the sensor cannot deliver the accuracy at the defined confidence level because it is a low-end sensor,
 - the sensor cannot calculate the accuracy due to lack of variables, or
 - there has been a vehicle bus (e.g. CAN bus) error.
 In all 3 cases above, the reported yaw rate value may be valid and used by the application.

 If a yaw rate value is received and its confidence is set to `outOfRange(7)`, it means that the reported
 yaw rate value is not valid and therefore cannot be trusted. Such value is not useful the application.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
YawRateConfidence ::= ENUMERATED {
    degSec-000-01 (0),
    degSec-000-05 (1),
    degSec-000-10 (2),
    degSec-001-00 (3),
    degSec-005-00 (4),
    degSec-010-00 (5),
    degSec-100-00 (6),
    outOfRange (7),
    unavailable (8)
}
```

### <a name="ProtectedZoneType"></a>ProtectedZoneType

DE that defines the type of a protected communication zone, so that an ITS-S is aware of the actions to do
 while passing by such zone (e.g. reduce the transmit power in case of a DSRC tolling station).

 The protected zone type is defined in ETSI TS 102 792 [i.16].

 The DE is used in [**ProtectedCommunicationZone**](#ProtectedCommunicationZone) DF as defined in clause A.121.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Communication information](#Communication+information)_

```asn1
ProtectedZoneType::= ENUMERATED { permanentCenDsrcTolling (0), ..., temporaryCenDsrcTolling (1) }
```

### <a name="RelevanceDistance"></a>RelevanceDistance

DE describing a distance of relevance for information indicated in a message, for example, it may be used
 to describe the distance of relevance of an event indicated in a DENM as defined in ETSI EN 302 637-3 [i.3].

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

```asn1
RelevanceDistance ::= ENUMERATED {lessThan50m(0), lessThan100m(1), lessThan200m(2), lessThan500m(3), lessThan1000m(4), lessThan5km(5), lessThan10km(6), over10km(7)}
```

### <a name="RelevanceTrafficDirection"></a>RelevanceTrafficDirection

DE describing a traffic direction that is relevant to information indicated in a message.
 For example, it may be used to describe traffic direction which is relevant to an event indicated by a DENM
 as defined in ETSI EN 302 637-3 [i.3],
 The terms `upstream`, `downstream` and `oppositeTraffic` are relative to the event position.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: Upstream traffic corresponds to the incoming traffic towards the event position,
 and downstream traffic to the departing traffic away from the event position.
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_

```asn1
RelevanceTrafficDirection ::= ENUMERATED {allTrafficDirections(0), upstreamTraffic(1), downstreamTraffic(2), oppositeTraffic(3)}
```

### <a name="TransmissionInterval"></a>TransmissionInterval

Time interval between two consecutive message transmissions.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _milliseconds_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Communication information](#Communication+information)_

```asn1
TransmissionInterval ::= INTEGER {oneMilliSecond(1), tenSeconds(10000)} (1..10000)
```

### <a name="ValidityDuration"></a>ValidityDuration

Duration of a traffic event validity.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _seconds_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Traffic information](#Traffic+information)_

```asn1
ValidityDuration ::=    INTEGER {timeOfDetection(0), oneSecondAfterDetection(1)} (0..86400)
```

### <a name="ActionID"></a>ActionID

Identifier used to describe a protocol action taken by an ITS-S.

 For example, it describes an action taken by an ITS-S to trigger a new DENM as defined in ETSI EN 302 637-3 [i.3]
 after detecting an event.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Communication information](#Communication+information)_

Fields:
* originatingStationID [**StationID**](#StationID) <br>
ID of the ITS-S that takes the action. It shall be presented as defined in clause A.77,

* originatingStationID [**StationID**](#StationID) <br>
* sequenceNumber [**SequenceNumber**](#SequenceNumber) <br>
a sequence number. It shall be presented as defined in clause A.68.

```asn1
ActionID ::= SEQUENCE {
    originatingStationID StationID,
    sequenceNumber SequenceNumber
}
```

### <a name="ItineraryPath"></a>ItineraryPath

A path being described with a list of waypoints, each waypoint is represented with geographical position
 as defined in clause A.124 [**ReferencePosition**](#ReferencePosition).

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_ 

```asn1
ItineraryPath ::= SEQUENCE SIZE(1..40) OF ReferencePosition
```

### <a name="ProtectedCommunicationZone"></a>ProtectedCommunicationZone

DF that describes a zone of protection inside which the ITSG5 communication should be restricted.

 &nbsp;&nbsp;&nbsp;&nbsp;**NOTE**: A protected communication zone may be defined around a CEN DSRC road side equipment.
 {: .note}

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Infrastructure information](#Infrastructure+information)_ _[Communication information](#Communication+information)_

Fields:
* protectedZoneType [**ProtectedZoneType**](#ProtectedZoneType) <br>
Type of the protected zone. It shall be presented as defined in clause A.58,

* protectedZoneType [**ProtectedZoneType**](#ProtectedZoneType) <br>
* expiryTime [**TimestampIts**](#TimestampIts)  OPTIONAL<br>
Time at which the validity of the protected communication zone will expire.
 It shall be presented as defined in clause A.82.
 This information is optional and shall be present when the  protected zone is temporarily valid,

* protectedZoneType [**ProtectedZoneType**](#ProtectedZoneType) <br>
* expiryTime [**TimestampIts**](#TimestampIts)  OPTIONAL<br>
* protectedZoneLatitude [**Latitude**](#Latitude) <br>
latitude of the centre point of the protected communication zone.
 It shall be presented as defined in clause A.41,

* protectedZoneType [**ProtectedZoneType**](#ProtectedZoneType) <br>
* expiryTime [**TimestampIts**](#TimestampIts)  OPTIONAL<br>
* protectedZoneLatitude [**Latitude**](#Latitude) <br>
* protectedZoneLongitude [**Longitude**](#Longitude) <br>
longitude of the centre point of the protected communication zone.
 It shall be represented as defined in clause A.44,

* protectedZoneType [**ProtectedZoneType**](#ProtectedZoneType) <br>
* expiryTime [**TimestampIts**](#TimestampIts)  OPTIONAL<br>
* protectedZoneLatitude [**Latitude**](#Latitude) <br>
* protectedZoneLongitude [**Longitude**](#Longitude) <br>
* protectedZoneRadius [**ProtectedZoneRadius**](#ProtectedZoneRadius)  OPTIONAL<br>
radius of the protected communication zone in metres.
 It shall be presented as defined in clause A.57.
 This DE is optional, it shall be present if the data is available,

* protectedZoneType [**ProtectedZoneType**](#ProtectedZoneType) <br>
* expiryTime [**TimestampIts**](#TimestampIts)  OPTIONAL<br>
* protectedZoneLatitude [**Latitude**](#Latitude) <br>
* protectedZoneLongitude [**Longitude**](#Longitude) <br>
* protectedZoneRadius [**ProtectedZoneRadius**](#ProtectedZoneRadius)  OPTIONAL<br>
* protectedZoneID [**ProtectedZoneID**](#ProtectedZoneID)  OPTIONAL<br>
the ID of the protected communication zone.
 It shall be presented as defined in clause A.56.
 This DE is optional, it shall be present if the data is available.

```asn1
ProtectedCommunicationZone ::= SEQUENCE {
    protectedZoneType       ProtectedZoneType,
    expiryTime TimestampIts OPTIONAL,
    protectedZoneLatitude   Latitude,
    protectedZoneLongitude  Longitude,
    protectedZoneRadius ProtectedZoneRadius OPTIONAL,
    protectedZoneID ProtectedZoneID OPTIONAL,
        ...
}
```

### <a name="Traces"></a>Traces

One or more paths, each path is described using a list of waypoints in a predefined order.
 A path shall be presented as defined in clause A.117 [**PathHistory**](#PathHistory).

 This DF may be used to describe location referencing information.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_ 

```asn1
Traces ::= SEQUENCE SIZE(1..7) OF PathHistory
```

### <a name="NumberOfOccupants"></a>NumberOfOccupants

Number of occupants in a vehicle.
 - For values equal to or higher than 126, the value shall be set to `126`.
 - If the information is not available, the value shall be set to `127`.
 @category Other information

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _1 person_

```asn1
NumberOfOccupants ::= INTEGER {oneOccupant (1), unavailable(127)} (0 .. 127)
```

### <a name="SequenceNumber"></a>SequenceNumber

Sequence number.

 The DE is used in [**ActionID**](#ActionID) as defined in clause A.102.
 @category Other information

```asn1
SequenceNumber ::=  INTEGER (0..65535)
```

### <a name="PositionOfPillars"></a>PositionOfPillars

Vehicle pillars refer to the vertical or near vertical support of vehicle,
 designated respectively as the A, B, C or D and other pillars moving in side profile view from the front to rear.

 The DF contains a list of distances that refer to the perpendicular distance between centre of vehicle front bumper
 and vehicle pillar A, between neighbour pillars until the last pillar of the vehicle.

 The first value of the DF refers to the perpendicular distance from the centre of vehicle front bumper to
 vehicle A pillar. The second value refers to the perpendicular distance from the centre position of A pillar
 to the B pillar of vehicle and so on until the last pillar.

 Each pillar position shall be presented as defined in clause A.54 [**PosPillar**](#PosPillar).

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Vehicle information](#Vehicle+information)_ 

```asn1
PositionOfPillars ::= SEQUENCE (SIZE(1..3, ...)) OF PosPillar
```

### <a name="RestrictedTypes"></a>RestrictedTypes

List of ITS-S types to which a certain traffic restriction, e.g. the speed limit, applies.

 Each station type shall be presented as defined in clause A.78 [**StationType**](#StationType).

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Infrastructure information](#Infrastructure+information)_ _[Traffic information](#Traffic+information)_ 

```asn1
RestrictedTypes ::= SEQUENCE (SIZE(1..3, ...)) OF StationType
```

### <a name="EventHistory"></a>EventHistory

The DF consists of a list of event points which represents the dimension of a plain event in a predefined order.
 In case that the plain event is detected by a vehicle ITS-S, the DF consists of a list of event detection points
 along the path that the detecting ITS S has travelled over some past time and/or distance.

 Each event point shall be presented as defined in clause A.111 [**EventPoint**](#EventPoint).

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_ _[Traffic information](#Traffic+information)_ 

```asn1
EventHistory::= SEQUENCE (SIZE(1..23)) OF EventPoint
```

### <a name="EventPoint"></a>EventPoint

DF that describes the position, time and corresponding information quality for an event point detected to describe
 a plain event.

 This DF is used in [**EventHistory**](#EventHistory) DF as defined in clause A.110.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_ _[Traffic information](#Traffic+information)_

Fields:
* eventPosition [**DeltaReferencePosition**](#DeltaReferencePosition) <br>
Offset position of a detected event point with regards to the previous detected event point.
 It shall be presented as defined in clause A.109.

* eventPosition [**DeltaReferencePosition**](#DeltaReferencePosition) <br>
* eventDeltaTime [**PathDeltaTime**](#PathDeltaTime)  OPTIONAL<br>
Time travelled by the detecting ITS-S since the previous detected event point.
 It shall be presented as defined in clause A.47.
 This field is optional, it shall be present if the information is available.

* eventPosition [**DeltaReferencePosition**](#DeltaReferencePosition) <br>
* eventDeltaTime [**PathDeltaTime**](#PathDeltaTime)  OPTIONAL<br>
* informationQuality [**InformationQuality**](#InformationQuality) <br>
Information quality of the detection for this event point.
 It shall be presented as defined in clause A.39.

```asn1
EventPoint ::= SEQUENCE {
    eventPosition DeltaReferencePosition,
    eventDeltaTime PathDeltaTime OPTIONAL,
    informationQuality InformationQuality
}
```

### <a name="ProtectedCommunicationZonesRSU"></a>ProtectedCommunicationZonesRSU

DF that describes a list of protected communication zones by a road side ITS-S (Road Side Unit RSU).

 It may provide up to 16 protected communication zones information.
 Each protected communication zone shall be presented as defined in clause A.121 [**ProtectedCommunicationZone**](#ProtectedCommunicationZone).

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Infrastructure information](#Infrastructure+information)_ _[Communication information](#Communication+information)_ 

```asn1
ProtectedCommunicationZonesRSU ::= SEQUENCE (SIZE(1..16)) OF ProtectedCommunicationZone
```

### <a name="CenDsrcTollingZone"></a>CenDsrcTollingZone

The DF describes the position of a CEN DSRC road side equipment.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Infrastructure information](#Infrastructure+information)_ _[Communication information](#Communication+information)_

Fields:
* protectedZoneLatitude [**Latitude**](#Latitude) <br>
the latitude of the CEN DSRC road side equipment.
 It shall be presented as defined in clause A.41,

* protectedZoneLatitude [**Latitude**](#Latitude) <br>
* protectedZoneLongitude [**Longitude**](#Longitude) <br>
the latitude of the CEN DSRC road side equipment.
 It shall be presented as defined in clause A.44,

* protectedZoneLatitude [**Latitude**](#Latitude) <br>
* protectedZoneLongitude [**Longitude**](#Longitude) <br>
* cenDsrcTollingZoneID [**CenDsrcTollingZoneID**](#CenDsrcTollingZoneID)  OPTIONAL<br>
the ID of the CEN DSRC road side equipment.
 It shall be presented as defined in clause A.11. This DE is optional.

```asn1
CenDsrcTollingZone ::= SEQUENCE {
    protectedZoneLatitude Latitude,
    protectedZoneLongitude Longitude,
    cenDsrcTollingZoneID CenDsrcTollingZoneID OPTIONAL,
        ...
}
```

### <a name="ProtectedZoneRadius"></a>ProtectedZoneRadius

Radius of a protected communication zone.

 This DE is used in [**ProtectedCommunicationZone**](#ProtectedCommunicationZone) DF as defined in clause A.121.

&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _metre_

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Infrastructure information](#Infrastructure+information)_ _[Communication information](#Communication+information)_

```asn1
ProtectedZoneRadius ::= INTEGER {oneMeter(1)} (1..255,...)
```

### <a name="ProtectedZoneID"></a>ProtectedZoneID

ID of a protected communication zone.

 This DE is used in [**CenDsrcTollingZoneID**](#CenDsrcTollingZoneID) DE as defined in clause A.11
 and in [**ProtectedCommunicationZone**](#ProtectedCommunicationZone) DF as defined in clause A.121.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Infrastructure information](#Infrastructure+information)_ _[Communication information](#Communication+information)_ 

```asn1
ProtectedZoneID ::= INTEGER (0.. 134217727)
```

### <a name="CenDsrcTollingZoneID"></a>CenDsrcTollingZoneID

ID of a CEN DSRC tolling zone. It shall be presented as defined in clause A.56 ProtectedZoneID.

 This DE is used in [**CenDsrcTollingZone**](#CenDsrcTollingZone) DF as defined in clause A.105.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Infrastructure information](#Infrastructure+information)_ _[Communication information](#Communication+information)_ 

```asn1
CenDsrcTollingZoneID ::= ProtectedZoneID
```

### <a name="DigitalMap"></a>DigitalMap

Portion of digital map, described using a list of waypoints, described as
 [**ReferencePosition**](#ReferencePosition) as defined in clause A.124.

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[GeoReference information](#GeoReference+information)_ 

```asn1
DigitalMap ::= SEQUENCE (SIZE(1..256)) OF ReferencePosition
```

### <a name="OpeningDaysHours"></a>OpeningDaysHours

UTF8String description of a time period to describe the opening days and hours of a Point of Interest
 (for example local commerce).

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Other information](#Other+information)_ 

```asn1
OpeningDaysHours ::= UTF8String
```

### <a name="PhoneNumber"></a>PhoneNumber

Phone number

&nbsp;&nbsp;&nbsp;&nbsp;**Categories**: _[Other information](#Other+information)_ 

```asn1
PhoneNumber ::= NumericString (SIZE(1..16))
```



